* {
	engine: adwaita;
	padding: 0;

	background-clip: padding-box;

	-GtkButton-child-displacement-x: 1;
	-GtkButton-child-displacement-y: 1;
	-GtkButtonBox-child-min-height: 26;

	-GtkToolButton-icon-spacing: 4;

	-GtkTextView-error-underline-color: @error_color;

	-GtkPaned-handle-size: 5;

	-GtkCheckButton-indicator-size: 16;
	-GtkCheckMenuItem-indicator-size: 12;

	/* The size for scrollbars. The slider is 2px smaller, but we keep it
	 * up so that the whole area is sensitive to button presses for the
	 * slider. The stepper button is larger in both directions, the slider
	 * only in the width
	 */

	-GtkScrolledWindow-scrollbar-spacing: 0;
	-GtkScrolledWindow-scrollbars-within-bevel: 1;

	-GtkToolItemGroup-expander-size: 11;
	-GtkExpander-expander-size: 11;
	-GtkTreeView-expander-size: 11;

	-GtkTreeView-horizontal-separator: 4;

	-GtkMenu-horizontal-padding: 0;
	-GtkMenu-vertical-padding: 0;

	-GtkWidget-link-color: @link_color;
	-GtkWidget-visited-link-color: @link_color;
	-GtkIMHtml-hyperlink-color: @link_color;
	-GtkHTML-link-color: @link_color;

	-WnckTasklist-fade-overlay-rect: 0;

	-GtkWidget-focus-padding: 2;
	-GtkWidget-focus-line-width: 1;
	-GtkWindow-resize-grip-width: 0;
	-GtkWindow-resize-grip-height: 0;

	/* We use the outline properties to signal the focus properties
	 * to the adwaita engine: using real CSS properties is faster,
	 * and we don't use any outlines for now.
	 */
	outline-color: alpha(@theme_text_color, 0.3);
	outline-style: dashed;
	outline-offset: 2px;
}

/***************
 * Base States *
 ***************/

.background {
	color: @theme_fg_color;
	background-color: @theme_bg_color;
}

.background:backdrop {
	text-shadow: none;
	icon-shadow: none;
}

/* FIXME: why do we still need this? */
GtkClutterOffscreen {
	background-color: @theme_bg_color;
	color: @theme_fg_color;
}

*:selected,
*:selected:focus {
	background-color: @theme_selected_bg_color;
	color: @theme_selected_fg_color;
}

*:selected:backdrop,
*:selected:focus:backdrop {
	background-color: @theme_unfocused_selected_bg_color;
	color: @theme_unfocused_selected_fg_color;
}

*:insensitive {
	background-color: @insensitive_bg_color;
	color: @insensitive_fg_color;
	border-color: @insensitive_borders;
}

*:insensitive:backdrop {
	text-shadow: none;
	icon-shadow: none;
	color: @unfocused_insensitive_fg_color;
}

/* Apply effects to insensitive and prelit images */
*:insensitive {
	-gtk-image-effect: dim;
}

*:hover {
	-gtk-image-effect: highlight;
}

.gtkstyle-fallback {
	background-color: @theme_bg_color;
	color: @theme_fg_color;
}

.gtkstyle-fallback:prelight {
	background-color: shade(@theme_bg_color, 1.10);
	color: @theme_fg_color;
}

.gtkstyle-fallback:active {
	background-color: shade(@theme_bg_color, 0.90);
	color: @theme_fg_color;
}

.gtkstyle-fallback:insensitive {
	background-color: @insensitive_bg_color;
	color: @insensitive_fg_color;
}

.gtkstyle-fallback:selected {
	background-color: @theme_selected_bg_color;
	color: @theme_selected_fg_color;
}

GtkImage,
GtkImage:insensitive,
GtkLabel,
GtkLabel:insensitive {
	background-color: transparent;
}

/************
 * Tooltips *
 ************/
.tooltip {
	padding: 4px;
	border-style: solid;
	border-width: 1px;
	border-color: shade(@theme_tooltip_bg_color, 0.50);
	border-radius: 0px;

	background-color: @theme_tooltip_bg_color;
	color: @theme_tooltip_fg_color;

	text-shadow: none;
}

.tooltip * {
	background-color: transparent;
}

/*****************
 * Miscellaneous *
 *****************/
@keyframes spinner {
	0.00% { background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(currentColor), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.875)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.750)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.625)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.500)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.375)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.250)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.125)), to(transparent)); }

	12.5% { background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.875)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.750)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.625)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.500)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.375)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.250)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.125)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(currentColor), to(transparent)); }

	25.0% { background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.750)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.625)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.500)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.375)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.250)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.125)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(currentColor), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.875)), to(transparent)); }

	37.5% { background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.625)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.500)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.375)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.250)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.125)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(currentColor), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.875)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.750)), to(transparent)); }

	50.0% { background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.500)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.375)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.250)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.125)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(currentColor), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.875)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.750)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.625)), to(transparent)); }

	62.5% { background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.375)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.250)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.125)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(currentColor), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.875)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.750)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.625)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.500)), to(transparent)); }

	75.0% { background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.250)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.125)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(currentColor), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.875)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.750)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.625)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.500)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.375)), to(transparent)); }

	87.5% { background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.125)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(currentColor), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.875)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.750)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.625)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.500)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.375)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.250)), to(transparent)); }

	100%  { background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(currentColor), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.875)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.750)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.625)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.500)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.375)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.250)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.125)), to(transparent)); }
}

.spinner {
	background-color: transparent;
	background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(currentColor), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(currentColor), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(currentColor), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(currentColor), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(currentColor), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(currentColor), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(currentColor), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(currentColor), to(transparent));
	background-position: 14% 14%, 0% 50%, 14% 86%, 50% 100%, 86% 86%, 100% 50%, 86% 14%, 50% 0%;
	background-size: 20% 20%;
	background-repeat: no-repeat;
}

.spinner:active {
	background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.875)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.750)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.625)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.500)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.375)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.250)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(alpha(currentColor, 0.125)), to(transparent)),
		-gtk-gradient(radial, center center, 0, center center, 0.5, to(currentColor), to(transparent));
	animation: spinner 1s infinite linear;
}

.button .spinner:active {
	color: @theme_fg_color;
}

.floating-bar {
	background-image: linear-gradient(to bottom, 
		@theme_base_color 20%, 
		shade(@theme_base_color, 0.9));
	background-color: @theme_base_color;
	border-color: @borders;

	color: @theme_text_color;
	text-shadow: 0 1px @button_text_shadow;
	border-radius: 3px;
	border-width: 1px;
	border-style: solid;
	box-shadow: inset 1px 1px @inset_light_color, -1px -1px @inset_light_color;
}

.floating-bar.top {
	border-top-width: 0;
	border-top-right-radius: 0;
	border-top-left-radius: 0;
}

.floating-bar.right {
	border-right-width: 0;
	border-top-right-radius: 0;
	border-bottom-right-radius: 0;
}

.floating-bar.bottom {
	border-bottom-width: 0;
	border-bottom-right-radius: 0;
	border-bottom-left-radius: 0;
}

.floating-bar.left {
	border-left-width: 0;
	border-top-left-radius: 0;
	border-bottom-left-radius: 0;
}

.floating-bar.bottom.right {
	box-shadow: inset 1px 1px @inset_light_color;
}

.floating-bar.bottom.left {
	box-shadow: inset -1px 1px @inset_light_color;
}

.floating-bar .button {
	background-color: alpha (@theme_base_color, 0.0);
	background-image: none;

	border-style: none;
	border-image: none;

	-GtkButton-image-spacing: 0;
	-GtkButton-inner-border: 0;
}

.content-view.view.rubberband,
.view.rubberband,
.rubberband {
	background-color: alpha (@theme_selected_bg_color, 0.35);

	border-color: @theme_selected_bg_color;
	border-style: solid;
	border-width: 1px;
	border-radius: 0px;
}

GtkStatusbar {
	padding: 5px;
	color: @theme_fg_color;
	-GtkStatusbar-shadow-type: none;
}

.dnd {
	border-width: 1px;
	border-style: solid;
	border-color: @theme_selected_bg_color;
	border-radius: 0;
}

GtkTreeView.view.separator,
GtkTreeView.separator,
.separator,
.separator:hover {
	color: @view_separators;
	background-color: transparent;
}

.toolbar .separator {
	/*color: @toolbar_separator;*/
	color: transparent;
}

.pane-separator {
	background-color: @theme_bg_color;
	color: shade (@inactive_frame_color, 0.80);
}

.pane-separator:hover,
.pane-separator:selected {
	color: @theme_text_color;
}

.notebook .pane-separator,
.notebook .pane-separator:hover {
	background-color: @theme_base_color;
}

/****************
 * Text Entries *
 ****************/
.entry {
	border-style: solid;
	padding: 4px;

	/* border-image defined in the -assets variants */

	color: @entry_text_color;
	background-color: @theme_base_color;
	box-shadow: inset 0px 2px 3px 0px alpha(@theme_fg_color, 0.15);
}

.entry:focus {
	box-shadow: inset 1px 2px alpha(@theme_selected_bg_color, 0.1),
		inset 1px 1px alpha(@theme_selected_bg_color, 0.1),
		inset -1px -1px alpha(@theme_selected_bg_color, 0.2);
}

.entry.progressbar,
.entry.progressbar:focus {
	margin-left: 2px;
	margin-right: 2px;
	border-image: none;
	border-style: none;
	background-color: transparent;
	background-image: linear-gradient(to top, 
		transparent 2px,
		white 2px,
		white 3px,
		shade(@theme_selected_bg_color, 0.9) 3px,
		shade(@theme_selected_bg_color, 0.9) 5px,
		transparent 5px);
	background-size: auto;
	box-shadow: none;
}

.entry.progressbar.pulse,
.entry.progressbar.pulse:focus {
	background-image: linear-gradient(to top, 
		transparent 2px,
		white 2px,
		white 3px,
		@borders 3px,
		@borders 5px,
		transparent 5px);
}

.entry:selected {
	color: @theme_selected_fg_color;
	background-color: @theme_selected_bg_color;
}

.entry:insensitive {
	color: @insensitive_fg_color;
}

/* needed for webkit/GtkStyle/Evolution compatibility */
GtkHTML:active,
.entry:active {
	color: @theme_unfocused_selected_fg_color;
	background-color: @theme_unfocused_selected_bg_color;
}

.cursor-handle.top,
.cursor-handle.bottom {
	background-color: transparent;
	box-shadow: none;
	border-style: none;
	border-image: none;
	border-radius: 0px;
	border-width: 0px;

	/* background-image in assets */
}

/*******************
 * Symbolic images *
 *******************/
.image {
	color: @internal_element_color;
}

.image:hover {
	color: @internal_element_prelight;
}

.image:selected,
.image:selected:hover {
	color: @theme_selected_fg_color;
}

.view.image,
.view.image:hover {
	color: @view_symbolic_color;
}

.view.image:selected,
.view.image:selected:hover {
	color: @theme_selected_fg_color;
}

/*****************
 * GtkSpinButton *
 *****************/
.spinbutton .button {
	color: @theme_fg_color;
	padding: 2px 6px;
	border-width: 0;
	border-radius: 0;
	border-style: none;
	border-image: none;
	box-shadow: inset 1px 0 @inset_dark_color;
}

.spinbutton .button {
	background-color: transparent;
	background-image: none;
}

.spinbutton .button:insensitive {
	color: @insensitive_fg_color;
}

.spinbutton .button:active,
.spinbutton .button:hover {
	color: @internal_element_color;
}

.spinbutton .button:first-child {
	border-radius: 4px 0 0 4px;
	box-shadow: none;
}

.spinbutton .button:last-child {
	border-radius: 0 4px 4px 0;
}

.spinbutton .button:dir(rtl) {
	box-shadow: inset -1px 0 @inset_dark_color;
}

/* Add back the glowy effect from the entry covered by the pushed button background*/
.spinbutton .button:active {
	box-shadow: inset 1px 0 @inset_dark_color,
		inset 0 1px alpha(@theme_selected_bg_color, 0.2),
		inset 0 -1px alpha(@theme_selected_bg_color, 0.2);
}

.spinbutton .button:first-child:active {
	box-shadow: inset 1px 1px alpha(@theme_selected_bg_color, 0.2),
		inset 0 -1px alpha(@theme_selected_bg_color, 0.2);
}

.spinbutton .button:last-child:active {
	box-shadow: inset 1px 0 @inset_dark_color,
		inset 0 1px alpha(@theme_selected_bg_color, 0.2),
		inset -1px -1px alpha(@theme_selected_bg_color, 0.2);
}


.spinbutton.vertical .button {
	padding: 4px;
	icon-shadow: 0 1px @button_text_shadow;
}

.spinbutton.vertical .button,
.spinbutton.vertical .button:hover {
	color: @theme_fg_color;
}

.spinbutton.vertical .button:insensitive {
	color: @insensitive_fg_color;
}

.spinbutton.vertical .button:active {
	color: @button_active_text;
	icon-shadow: 0 1px @button_active_text_shadow;
}

/* :insensitive:insensitive to override the dark overriden style for
   normal spinbutton buttons, yeah we lack !important */
.spinbutton.vertical .button:insensitive:insensitive {
	icon-shadow: none;
}

.spinbutton.vertical .button,
/* :active:active to override the dark overriden style for
   normal spinbutton buttons, yeah we lack !important */
.spinbutton.vertical .button:active:active {
	box-shadow: none;
}

.spinbutton.vertical .button:first-child {
	border-image-width: 3px 3px 0 3px;
	border-width: 1px 1px 0 1px;
	border-radius: 4px 4px 0 0;
}

.spinbutton.vertical .button:last-child {
	border-image-width: 0 3px 4px 3px;
	border-width: 0 1px 2px 1px;
	border-radius: 0 0 4px 4px;
}

.spinbutton.vertical.entry {
	/*border-image: none;*/
	border-image-width: 0px 3px 0 3px;
	border-color: @borders;
	border-width: 0 1px;
	border-style: solid;
	border-radius: 0;
	box-shadow: inset 0 2px @entry_inset, 
		inset 0 3px alpha(@entry_inset, 0.4),
		inset 0 1px @borders, 
		inset 0 -1px @borders;

	/* I'm using box-shadow as borders, so I need to compensate
	   with padding. Those two values need to be entry padding +1 */
	padding-top: 5px;
	padding-bottom: 5px;
}

.spinbutton.vertical.entry:insensitive {
	border-color: @insensitive_borders;
	box-shadow: inset 0 1px @insensitive_borders, 
		inset 0 -1px @insensitive_borders;
}

.spinbutton.vertical.entry:focus {
	border-color: @theme_selected_bg_color;
	box-shadow: inset 1px 2px alpha(@theme_selected_bg_color, 0.1), 
		inset 1px 3px alpha(@theme_selected_bg_color, 0.1),
		inset -1px -2px alpha(@theme_selected_bg_color, 0.2),
		inset 0 1px @theme_selected_bg_color,
		inset 0 -1px @theme_selected_bg_color;
}

/*****************
 * Color Chooser *
 *****************/
GtkColorSwatch,
GtkColorSwatch:selected {
	border-width: 1px;
	border-style: solid;
	border-radius: 1px;
	border-color: alpha(black, 0.3);
	box-shadow: inset 0 2px alpha(black, 0.07),
		inset 1px 1px alpha(black, 0.07);

	background-color: transparent;
	background-clip: border-box;
}

GtkColorSwatch:hover,
GtkColorSwatch:selected:hover {
	border-color: alpha(black, 0.45);
}

GtkColorSwatch.color-dark:hover {
	background-image: linear-gradient(to bottom,
		alpha(white, 0) 40%,
		alpha(white, 0.3)
		);
}

GtkColorSwatch.color-light:hover {
	background-image: linear-gradient(to top,
		alpha(black, 0) 40%,
		alpha(black, 0.1)
		);
}

GtkColorSwatch.color-light:selected:hover,
GtkColorSwatch.color-dark:selected:hover {
	background-image: none;
}

GtkColorSwatch.left,
GtkColorSwatch:first-child {
	border-top-left-radius: 6px;
	border-bottom-left-radius: 6px;
}

GtkColorSwatch.right,
GtkColorSwatch:last-child {
	border-top-right-radius: 6px;
	border-bottom-right-radius: 6px;
}

GtkColorSwatch:only-child {
	border-radius: 6px;
}

GtkColorSwatch.top {
	border-top-left-radius: 6px;
	border-top-right-radius: 6px;
}

GtkColorSwatch.bottom {
	border-bottom-left-radius: 6px;
	border-bottom-right-radius: 6px;
}

GtkColorChooserWidget #add-color-button {
	background-clip: padding-box;
	border-color: mix(@borders, @theme_bg_color, 0.3);
	background-color: mix(@borders, @theme_bg_color, 0.3);
	color: @theme_base_color;
	box-shadow: none;
}

GtkColorChooserWidget #add-color-button:hover {
	border-color: @borders;
	background-color: @borders;
	color: @theme_base_color;
}

.color-active-badge,
.color-active-badge:selected {
	border-style: solid;
	border-width: 2px;
	background-color: transparent;
}

.color-active-badge.color-light,
.color-active-badge.color-light:hover {
	border-color: #444444;
	color: #444444;
}

.color-active-badge.color-dark,
.color-active-badge.color-dark:hover {
	border-color: #cccccc;
	color: #cccccc;
}

GtkColorEditor GtkColorSwatch {
	border-radius: 6px;
}

GtkColorEditor GtkColorSwatch.color-dark:hover,
GtkColorEditor GtkColorSwatch.color-light:hover {
	background-image: none;
	border-color: alpha(black, 0.3);
}

GtkColorButton.button {
	padding: 1px 20px;
}

/****************
 * Progress bar *
 ****************/

/* FIXME: this should really be a margin... */
GtkProgressBar {
	-GtkProgressBar-min-horizontal-bar-height: 16;
	-GtkProgressBar-min-vertical-bar-width: 16;
	border-radius: 16px;
	padding: 0 0 1px 0;
}

/* progress component */
.progressbar,
.progressbar row,
.progressbar row:hover,
.progressbar row:selected,
.progressbar row:selected:focus {
	border-radius: 16px;
	border-width: 1px;
	border-style: solid;
	border-color: @progressbar_border;
}

.progressbar row:selected,
.progressbar row:selected:focus {
	border-color: shade(@progressbar_border, 0.85);
}

/* for progressbars in cell renderers */
.trough row {
	padding: 0;
}

.trough row:selected,
.trough row:selected:focus {
	background-image: linear-gradient(to bottom,
		mix(@trough_bg_color_a, @theme_selected_bg_color, 0.25),
		mix(@trough_bg_color_b, @theme_selected_bg_color, 0.25)
		);
}

/* level bars as used for password quality or remaining power */
GtkLevelBar {
	-GtkLevelBar-min-block-width: 34;
	-GtkLevelBar-min-block-height: 3;
}

GtkLevelBar.vertical {
	-GtkLevelBar-min-block-width: 3;
	-GtkLevelBar-min-block-height: 34;
}

.level-bar.trough {
	padding: 2px;
	border-radius: 8px;
	background-image: linear-gradient(to bottom,
		@trough_bg_color_a,
		@trough_bg_color_b);
	background-color: transparent;
	box-shadow: inset 0 0 0 1px @borders;
}


.level-bar.fill-block {
	border-width: 1px;
	border-style: solid;

	border-color: @progressbar_border;
	background-image: linear-gradient(to bottom,
		@progressbar_background_a,
		@progressbar_background_b);
}

.level-bar.indicator-continuous.fill-block {
	padding: 2px;
	border-radius: 8px;
}

.level-bar.indicator-discrete.fill-block.horizontal {
	margin: 0 1px;
}

.level-bar.indicator-discrete.fill-block.vertical {
	margin: 1px 0;
}

/* discrete indicator border rounding,
   uncomment when :nth-child will be working
   on the widget

.level-bar.indicator-discrete.fill-block.horizontal:first-child {
	border-radius: 2px 0 0 2px;
}

.level-bar.indicator-discrete.fill-block.horizontal:last-child {
	border-radius: 0 2px 2px 0;
}

.level-bar.indicator-discrete.fill-block.vertical:first-child {
	border-radius: 2px 2px 0 0;
}

.level-bar.indicator-discrete.fill-block.vertical:last-child {
	border-radius: 0 0 2px 2px;
}

*/

.level-bar.fill-block.level-high {
	border-color: shade(@success_color, 0.85);
	background-image: linear-gradient(to bottom,
		shade(@success_color, 1.2),
		@success_color 75%,
		shade(@success_color, 0.95));
}

.level-bar.fill-block.level-low {
	border-color: shade(@warning_color, 0.80);
	background-image: linear-gradient(to bottom,
		shade(@warning_color, 1.3),
		@warning_color 75%,
		shade(@warning_color, 0.90));
}

.level-bar.fill-block.empty-fill-block {
	background-color: transparent;
	background-image: none;
	border-color: alpha(@theme_fg_color, 0.1);
}

/************
 * GtkScale *
 ************/

.scale {
	-GtkScale-slider-length: 16;
	-GtkRange-slider-width: 16;
	-GtkRange-trough-border: 0;
}

.scale.slider,
.scale.slider:hover,
.scale.slider:insensitive {
	border-radius: 0;
	border-style: none;

	background-color: transparent;

	/* background-image in -assets variant */
}

.scale.slider.fine-tune:active,
.scale.slider.fine-tune:active:hover,
.scale.slider.fine-tune.horizontal:active,
.scale.slider.fine-tune.horizontal:active:hover {
	background-size: 50%;
	background-repeat: no-repeat;
	background-position: center;
}

.scale.trough {
	margin: 6px 0;
	border-radius: 6px;
}

.scale.trough.vertical {
	margin: 0 6px;
}

.scale.trough,
.scale.trough.highlight {
	border-color: alpha(@theme_base_color, 0.0);
	border-top: 0;
	border-left: 0;
	border-right: 0;
	border-bottom: 1px;
}

.scale.trough.vertical,
.scale.trough.highlight.vertical {
	border-color: alpha(@theme_base_color, 0.0);
	border-top: 0;
	border-left: 0;
	border-right: 1px;
	border-bottom: 0;
}

.scale.trough,
.scale.trough.vertical {
	border-color: @borders;
}

.scale.trough.highlight,
.scale.trough.highlight.vertical {
	border-color: @scale_highlight_border;
}

.scale.trough:insensitive,
.scale.trough.highlight:insensitive,
.scale.trough.vertical:insensitive,
.scale.trough.highlight.vertical:insensitive {
	background-color: shade(@insensitive_bg_color, 0.96);
	border-color: shade(@insensitive_scale_borders, 1.0);
	box-shadow: none;
	background-image: none;
}

.scale.trough.highlight,
.scale.trough.vertical.highlight {
	background-image: none;
	background-color: @scale_highlight_bg;
}

.scale.progressbar {
	background-color: @scale_progress_fill;
}

.scale.mark.separator {
	/* defines the color of the actuall marks on the scale */
	color: alpha(@theme_fg_color, 0.3);
}

.scale.trough {
	box-shadow: inset 0 1px shade(@theme_bg_color, 0.85),
		inset 0 -1px alpha(@theme_base_color, 0.4);
}

.scale.trough.vertical {
	box-shadow: inset 1px 0 shade(@theme_bg_color, 0.85),
		inset -1px 0 alpha(@theme_base_color, 0.4);
}

.scale.trough.highlight {
	box-shadow: inset 0 1px alpha(@theme_base_color, 0.2),
		inset 0 -1px shade(@theme_selected_bg_color, 0.7);
}

.scale.trough.vertical.highlight {
	box-shadow: inset 1px 0 alpha(@theme_base_color, 0.2),
		inset -1px 0 shade(@theme_selected_bg_color, 0.7);
}

/**********
 * Frames *
 **********/
.frame {
	border-width: 1px;
	border-color: @borders;
	border-style: solid;
	padding: 0;
}

GtkScrolledWindow.frame {
	border-style: solid;
	border-color: @borders;
	border-width: 1px;
	border-radius: 2px;
	padding: 0;
}

/* avoid double borders when a viewport is 
 * packed into a GtkScrolledWindow */
GtkScrolledWindow GtkViewport.frame {
	border-style: none;
}

/***********
 * Buttons *
 ***********/
.button,
.button.menuitem.menubar,
GtkColorButton.button,
GtkComboBox.combobox-entry .button {
	padding: 1px 4px;
}

.button.image-button {
	padding: 3px 4px 4px;
}

.button {
	-GtkButton-image-spacing: 4;
	-GtkButton-interior-focus: true;
	-GtkButton-default-border: 0;
	-GtkButton-inner-border: 3;

	border-style: solid;
	border-color: transparent;

	text-shadow: 0 1px @button_text_shadow;
}

/* We may want a background for focused buttons, but in the meantime let's remove it too */
.primary-toolbar .button,
.primary-toolbar .button:insensitive {
	background-image: none;
	background-color: transparent;
}

/* Remove borders from primary toolbar buttons*/
.primary-toolbar .button {
	border-image: none;

	/* setting border-style: none; here would override the border-width values 
	 * we set in gtk-widget-borders.css to zero.
	 */
	border-style: solid;
	border-width: 2px;
	border-color: transparent;

	text-shadow: 0 1px @button_text_shadow;
}

.primary-toolbar.toolbar .button.image-button {
	padding: 3px 4px 4px;
}

.primary-toolbar .button:active,
.inline-toolbar .button:active,
.button:active {
	color: @button_active_text;
	text-shadow: 0 1px @button_active_text_shadow;
}

.button:insensitive,
.button:active *:insensitive {
	color: @insensitive_fg_color;
	text-shadow: none;
}

.toolbar .button.raised,
.toolbar .raised .button,
.inline-toolbar .button {
	icon-shadow: 0 1px @button_text_shadow;
	text-shadow: 0 1px @button_text_shadow;
}

.toolbar .button.raised:active,
.toolbar .raised .button:active,
.inline-toolbar .button:active {
	icon-shadow: 0 1px @button_active_text_shadow;
	text-shadow: 0 1px @button_active_text_shadow;
}

.toolbar .button.raised:insensitive,
.toolbar .raised .button:insensitive,
.inline-toolbar .button:insensitive {
	icon-shadow: none;
	text-shadow: none;
}

/* linked entries/buttons */

/* Set up shadows and hilights for button visual separation */
.linked .entry {
	box-shadow: inset -1px 0 @inset_dark_color;
}

.linked .entry:focus {
	box-shadow: inset 1px 0 @inset_dark_color,
		inset -1px 0 @inset_dark_color,
		inset 1px 2px alpha(@theme_selected_bg_color, 0.1),
		inset 1px 1px alpha(@theme_selected_bg_color, 0.1),
		inset -1px -1px alpha(@theme_selected_bg_color, 0.2);

}

.linked .entry:focus:first-child {
	box-shadow: inset -1px 0 @inset_dark_color,
		inset 1px 2px alpha(@theme_selected_bg_color, 0.1),
		inset 1px 1px alpha(@theme_selected_bg_color, 0.1),
		inset -1px -1px alpha(@theme_selected_bg_color, 0.2);

}

.linked .entry:focus:last-child {
	box-shadow: inset 1px 0 @inset_dark_color,
		inset 1px 2px alpha(@theme_selected_bg_color, 0.1),
		inset 1px 1px alpha(@theme_selected_bg_color, 0.1),
		inset -1px -1px alpha(@theme_selected_bg_color, 0.2);

}

/* Set up shadows and hilights for button visual separation */
.linked .button,
.toolbar .button.raised.linked,
.toolbar .raised.linked .button,
.inline-toolbar.toolbar .button,
.inline-toolbar.toolbar GtkToolButton > .button {
	box-shadow: inset 1px 0 @inset_light_color, inset -1px 0 @inset_dark_color;
}

.linked .button:first-child,
.toolbar .button.raised.linked:first-child,
.toolbar .raised.linked .button:first-child,
.inline-toolbar.toolbar .button:first-child,
.inline-toolbar.toolbar GtkToolButton:first-child > .button {
	box-shadow: inset -1px 0 @inset_dark_color;
}

.linked .button:last-child,
.toolbar .button.raised.linked:last-child,
.toolbar .raised.linked .button:last-child,
.inline-toolbar.toolbar .button:last-child,
.inline-toolbar.toolbar GtkToolButton:last-child > .button {
	box-shadow: inset 1px 0 @inset_light_color;
}

.linked .button:active,
.toolbar .button.raised.linked:active,
.toolbar .raised.linked .button:active,
.inline-toolbar.toolbar .button:active,
.inline-toolbar.toolbar GtkToolButton > .button:active {
	box-shadow: inset 1px 0 @inset_dark_color;
}

.linked .button:insensitive,
.toolbar .button.raised.linked:insensitive,
.toolbar .raised.linked .button:insensitive,
.inline-toolbar.toolbar .button:insensitive,
.inline-toolbar.toolbar GtkToolButton > .button:insensitive {
	box-shadow: inset -1px 0 @inset_dark_color;
}

/* remove box shadow from last-child and only-child */
.linked .button:insensitive:last-child,
.linked .button:only-child,
.toolbar .button.raised.linked:insensitive:last-child,
.toolbar .raised.linked .button:insensitive:last-child,
.inline-toolbar.toolbar .button:insensitive:last-child,
.inline-toolbar.toolbar .button:only-child,
.inline-toolbar.toolbar GtkToolButton:last-child > .button:insensitive,
.inline-toolbar.toolbar GtkToolButton:only-child > .button {
	box-shadow: none; 
}

/* Middle button */
.linked .entry,
.linked .button,
.linked .button:active,
.linked .button:active:hover,
.linked .button:insensitive {
	border-right-width: 0;
	border-left-width: 0;
	border-image-width: 3px 0 4px 0;
	border-radius: 0;
}

/* Leftmost button */
.linked .entry:first-child,
.linked .button:first-child,
.linked .button:active:first-child,
.linked .button:active:hover:first-child,
.linked .button:insensitive:first-child {
	border-left-width: 2px;
	border-image-width: 3px 0 4px 4px;
	border-bottom-right-radius: 0;
	border-top-right-radius: 0;
}

/* Rightmost button */
.linked .entry:last-child,
.linked .button:last-child,
.linked .button:active:last-child,
.linked .button:active:hover:last-child,
.linked .button:insensitive:last-child {
	border-right-width: 2px;
	border-left-width: 0;
	border-image-width: 3px 4px 4px 0;
	border-bottom-left-radius: 0;
	border-top-left-radius: 0;
}

/* Linked single button */
.linked .entry:only-child,
.linked .button:only-child,
.linked .button:active:only-child,
.linked .button:active:hover:only-child,
.linked .button:insensitive:only-child {
	border-right-width: 1px;
	border-left-width: 1px;
	border-image-width: 3px 4px 4px 4px;
	border-radius: 3px;
}

/* Middle button (vertical) */
.linked.vertical .entry,
.linked.vertical .button,
.linked.vertical .button:active,
.linked.vertical .button:active:hover,
.linked.vertical .button:insensitive {
	border-top-width: 0;
	border-bottom-width: 0;
	border-image-width: 0 4px;
	border-radius: 0;
}

/* Top button (vertical) */
.linked.vertical .entry:first-child,
.linked.vertical .button:first-child,
.linked.vertical .button:active:first-child,
.linked.vertical .button:active:hover:first-child,
.linked.vertical .button:insensitive:first-child {
	border-bottom-width: 0;
	border-image-width: 3px 4px 0 4px;
	border-radius: 4px 4px 0 0;
}

/* Bottom button (vertical) */
.linked.vertical .entry:last-child,
.linked.vertical .button:last-child,
.linked.vertical .button:active:last-child,
.linked.vertical .button:active:hover:last-child,
.linked.vertical .button:insensitive:last-child {
	border-top-width: 0;
	border-image-width: 0 4px 4px 4px;
	border-radius: 0 0 4px 4px;
}

/* Linked single button (vertical) */
.linked.vertical .entry:only-child,
.linked.vertical .button:only-child,
.linked.vertical .button:active:only-child,
.linked.vertical .button:active:hover:only-child,
.linked.vertical .button:insensitive:only-child {
	border-top-width: 1px;
	border-bottom-width: 1px;
	border-image-width: 3px 4px 4px 4px;
	border-radius: 4px;
}

/* Linked button shadows (vertical) */
.linked.vertical .button,
.inline-toolbar.toolbar.vertical .button,
.inline-toolbar.toolbar.vertical GtkToolButton > .button {
	box-shadow: inset 0 1px @inset_light_color, inset 0 -1px @inset_dark_color;
}

.linked.vertical .button:first-child,
.inline-toolbar.toolbar.vertical .button:first-child,
.inline-toolbar.toolbar.vertical GtkToolButton:first-child > .button {
	box-shadow: inset 0 -1px @inset_dark_color;
}

.linked.vertical .button:last-child,
.inline-toolbar.toolbar.vertical .button:last-child,
.inline-toolbar.toolbar.vertical GtkToolButton:last-child > .button {
	box-shadow: inset 0 -1px @inset_light_color;
}

.linked.vertical .button:active,
.inline-toolbar.toolbar.vertical .button:active,
.inline-toolbar.toolbar.vertical GtkToolButton > .button:active {
	box-shadow: inset 0 1px @inset_dark_color, inset 0 -1px @inset_dark_color;
}

.linked.vertical .button:insensitive,
.inline-toolbar.toolbar.vertical .button:insensitive,
.inline-toolbar.toolbar.vertical GtkToolButton > .button:insensitive {
	box-shadow: inset 0 -1px @inset_dark_color;
}

.linked.vertical .button:only-child,
.linked.vertical .button:insensitive:last-child,
.inline-toolbar.toolbar.vertical .button:insensitive:last-child,
.inline-toolbar.toolbar.vertical .button:only-child,
.inline-toolbar.toolbar.vertical GtkToolButton:last-child > .button:insensitive,
.inline-toolbar.toolbar.vertical GtkToolButton:only-child > .button {
	box-shadow: none;
}

/* Linked buttons on primary toolbars */

/* Middle button */
.primary-toolbar .button.raised.linked,
.primary-toolbar .button.raised.linked:active,
.primary-toolbar .button.raised.linked:insensitive,
.primary-toolbar .linked .entry,
.primary-toolbar .linked .button,
.primary-toolbar .linked .button:active,
.primary-toolbar .linked .button:insensitive,
.inline-toolbar.toolbar .button,
.inline-toolbar.toolbar .button:active,
.inline-toolbar.toolbar .button:insensitive,
.inline-toolbar.toolbar GtkToolButton > .button,
.inline-toolbar.toolbar GtkToolButton > .button:active,
.inline-toolbar.toolbar GtkToolButton > .button:insensitive {
	border-right-width: 0;
	border-left-width: 0;
	border-image-width: 3px 0 4px 0;
	border-radius: 0;
}

/* Leftmost button */
.primary-toolbar .button.raised.linked:first-child,
.primary-toolbar .button.raised.linked:active:first-child,
.primary-toolbar .button.raised.linked:insensitive:first-child,
.primary-toolbar .linked .entry:first-child,
.primary-toolbar .linked .button:first-child,
.primary-toolbar .linked .button:active:first-child,
.primary-toolbar .linked .button:insensitive:first-child,
.inline-toolbar.toolbar .button:first-child,
.inline-toolbar.toolbar .button:active:first-child,
.inline-toolbar.toolbar .button:insensitive:first-child,
.inline-toolbar.toolbar GtkToolButton:first-child > .button,
.inline-toolbar.toolbar GtkToolButton:first-child > .button:active,
.inline-toolbar.toolbar GtkToolButton:first-child > .button:insensitive {
	border-left-width: 2px;
	border-right-width: 0;
	border-image-width: 3px 0 4px 3px;
	border-bottom-right-radius: 0;
	border-top-right-radius: 0;
}

/* Rightmost button */
.primary-toolbar .button.raised.linked:last-child,
.primary-toolbar .button.raised.linked:active:last-child,
.primary-toolbar .button.raised.linked:insensitive:last-child,
.primary-toolbar .linked .entry:last-child,
.primary-toolbar .linked .button:last-child,
.primary-toolbar .linked .button:active:last-child,
.primary-toolbar .linked .button:insensitive:last-child,
.inline-toolbar.toolbar .button:last-child,
.inline-toolbar.toolbar .button:active:last-child,
.inline-toolbar.toolbar .button:insensitive:last-child,
.inline-toolbar.toolbar GtkToolButton:last-child > .button,
.inline-toolbar.toolbar GtkToolButton:last-child > .button:active,
.inline-toolbar.toolbar GtkToolButton:last-child > .button:insensitive {
	border-left-width: 0;
	border-right-width: 2px;
	border-image-width: 3px 3px 4px 0;
	border-bottom-left-radius: 0;
	border-top-left-radius: 0;
	box-shadow: none;
}

/* Single button */
.inline-toolbar.toolbar .button:only-child,
.inline-toolbar.toolbar .button:active:only-child,
.inline-toolbar.toolbar .button:insensitive:only-child,
.inline-toolbar.toolbar GtkToolButton:only-child > .button,
.inline-toolbar.toolbar GtkToolButton:only-child > .button:active,
.inline-toolbar.toolbar GtkToolButton:only-child > .button:insensitive {
	border-right-width: 2px;
	border-left-width: 2px;
	border-image-width: 3px 3px 4px 3px;
	border-radius: 4px;
}

/* Special-case GtkMenuToolButton, since it's a GtkToolButton, but it
 * has a box inside to pack the button and the actual menu */
.inline-toolbar.toolbar GtkMenuToolButton .button:first-child,
.inline-toolbar.toolbar GtkMenuToolButton .button:active:first-child,
.inline-toolbar.toolbar GtkMenuToolButton .button:insensitive:first-child,
.inline-toolbar.toolbar GtkMenuToolButton .button:last-child,
.inline-toolbar.toolbar GtkMenuToolButton .button:active:last-child,
.inline-toolbar.toolbar GtkMenuToolButton .button:insensitive:last-child {
	border-right-width: 0;
	border-left-width: 0;
	border-image-width: 3px 0 4px 0;
	border-radius: 0;
}

.inline-toolbar.toolbar GtkMenuToolButton:first-child .button:first-child,
.inline-toolbar.toolbar GtkMenuToolButton:first-child .button:active:first-child,
.inline-toolbar.toolbar GtkMenuToolButton:first-child .button:insensitive:first-child {
	border-left-width: 2px;
	border-right-width: 0;
	border-image-width: 3px 3px 4px 0;
	border-bottom-right-radius: 0;
	border-top-right-radius: 0;
}

.inline-toolbar.toolbar GtkMenuToolButton:last-child .button:last-child,
.inline-toolbar.toolbar GtkMenuToolButton:last-child .button:active:last-child,
.inline-toolbar.toolbar GtkMenuToolButton:last-child .button:insensitive:last-child {
	border-left-width: 0;
	border-right-width: 2px;
	border-image-width: 3px 3px 4px 0;
	border-bottom-left-radius: 0;
	border-top-left-radius: 0;
}

/* Vertical inline toolbars */

/* Middle button */
.inline-toolbar.toolbar.vertical .button,
.inline-toolbar.toolbar.vertical .button:active,
.inline-toolbar.toolbar.vertical .button:insensitive,
.inline-toolbar.toolbar.vertical GtkToolButton > .button,
.inline-toolbar.toolbar.vertical GtkToolButton > .button:active,
.inline-toolbar.toolbar.vertical GtkToolButton > .button:insensitive {
	border-bottom-width: 0;
	border-top-width: 0;
	border-image-width: 0 3px 0 3px;
	border-radius: 0;
}

/* Topmost button */
.inline-toolbar.toolbar.vertical .button:first-child,
.inline-toolbar.toolbar.vertical .button:active:first-child,
.inline-toolbar.toolbar.vertical .button:insensitive:first-child,
.inline-toolbar.toolbar.vertical GtkToolButton:first-child > .button,
.inline-toolbar.toolbar.vertical GtkToolButton:first-child > .button:active,
.inline-toolbar.toolbar.vertical GtkToolButton:first-child > .button:insensitive {
	border-width: 1px 1px 0 1px;
	border-image-width: 3px 3px 0 3px;
	border-bottom-left-radius: 0;
	border-bottom-right-radius: 0;
}

/* Bottommost button */
.inline-toolbar.toolbar.vertical .button:last-child,
.inline-toolbar.toolbar.vertical .button:active:last-child,
.inline-toolbar.toolbar.vertical .button:insensitive:last-child,
.inline-toolbar.toolbar.vertical GtkToolButton:last-child > .button,
.inline-toolbar.toolbar.vertical GtkToolButton:last-child > .button:active,
.inline-toolbar.toolbar.vertical GtkToolButton:last-child > .button:insensitive {
	border-width: 0 1px 2px 1px;
	border-image-width: 0 3px 4px 3px;
	border-top-left-radius: 0;
	border-top-right-radius: 0;
}

/* Single button */
.inline-toolbar.toolbar.vertical .button:only-child,
.inline-toolbar.toolbar.vertical .button:active:only-child,
.inline-toolbar.toolbar.vertical .button:insensitive:only-child,
.inline-toolbar.toolbar.vertical GtkToolButton:only-child > .button,
.inline-toolbar.toolbar.vertical GtkToolButton:only-child > .button:active,
.inline-toolbar.toolbar.vertical GtkToolButton:only-child > .button:insensitive {
	border-top-width: 1px;
	border-bottom-width: 2px;
	border-image-width: 3px 3px 3px 4px;
	border-radius: 3px;
}

GtkLinkButton.button,
GtkLinkButton.button:active {
	text-shadow: none;
}

.button .separator { 
	color: shade(@internal_element_color, 1.30);
}

/*****************
 * Notebooks and *
 * tabs		*
 *****************/
.notebook {
	/* To get rid of the horrible adwaita tabs we need the notebook to use no engine */
	engine: none;
	padding: 0;

	border-color: @borders;
	border-style: solid;
	border-width: 1px;

	background-color: shade (@theme_bg_color, 1.1);
	-GtkNotebook-initial-gap: 0;
	-GtkNotebook-arrow-spacing: 5;
	-GtkNotebook-has-tab-gap: false;
	-GtkNotebook-tab-overlap: -1;
}

.notebook.header {
	background-color: shade(@theme_bg_color, 0.95);
	box-shadow: inset 0 3px alpha(black, 0.03), inset 0 2px alpha(black, 0.03), inset 0 1px alpha(black, 0.03);
	border-width: 0px;
}

.notebook.header.frame.top {
	border-top: 1px solid @borders;
	border-left: 1px solid @borders;
	border-right: 1px solid @borders;
}

.notebook.header.frame.bottom {
	border-bottom: 1px solid @borders;
	border-left: 1px solid @borders;
	border-right: 1px solid @borders;
}

.notebook.header.frame.left {
	border-top: 1px solid @borders;
	border-bottom: 1px solid @borders;
	border-left: 1px solid @borders;
}

.notebook.header.frame.right {
	border-top: 1px solid @borders;
	border-bottom: 1px solid @borders;
	border-right: 1px solid @borders;
}

.notebook GtkViewport {
	background-color: shade (@theme_bg_color, 1.1);
	border-width: 0px;
}

.notebook tab {
	padding: 2px;
	border-style: solid;
	border-width: 1px 1px 0px 1px;
	border-color: @borders;
	background-image: linear-gradient(to bottom,
		@notebook_tab_gradient_a,
		@notebook_tab_gradient_b);
	border-radius: 4px 4px 0 0;
	border-image: none;
	box-shadow: inset 0 1px alpha (shade (@theme_base_color, 1.1), 0.4);;
}

.notebook tab.bottom {
	background-image: linear-gradient(to top,
		@notebook_tab_gradient_a,
		@notebook_tab_gradient_b);
	border-width: 0px 1px 1px 1px;
	border-radius: 0 0 4px 4px;
	box-shadow: inset 0 -1px alpha (shade (@theme_base_color, 1.1), 0.4);
}

.notebook tab:active {
	background-image: linear-gradient(to bottom,
		shade (@theme_bg_color, 1.18),
		shade (@theme_bg_color, 1.1));
	border-width: 1px 1px 0px 1px;
}

.notebook tab.bottom:active {
	background-image: linear-gradient(to bottom,
		shade (@theme_bg_color, 1.1),
		shade (@theme_bg_color, 1.18));
	border-width: 0px 1px 1px 1px;
}

.notebook tab.left,
.notebook tab.right {
	background-image: none;
	background-color: @theme_bg_color;
	padding: 3px;
}

.notebook tab.left {
	border-width: 1px 0 1px 1px;
	border-radius: 4px 0 0 4px;
}

.notebook tab.right {
	border-width: 1px 1px 1px 0;
	border-radius: 0 4px 4px 0;
}

.notebook tab.left:active,
.notebook tab.right:active {
	background-image: none;
	background-color: shade (@theme_bg_color, 1.1);
}

.notebook tab.left:active {
	border-width: 1px 0 1px 1px;
	padding: 3px 3px 3px 5px;
	border-radius: 4px 0 0 4px;
}

.notebook tab.right:active {
	border-width: 1px 1px 1px 0;
	padding: 3px 5px 3px 3px;
	border-radius: 0 4px 4px 0;
}

.notebook tab GtkLabel {
	color: @theme_fg_color;
}

.notebook .active-page,
.notebook tab .active-page GtkLabel {
	color: @theme_fg_color;
}

.notebook tab:active {
	border-bottom-width: 0px;
}

/* close button styling */
.notebook tab .button,
.notebook tab .button:active,
.notebook tab .button:hover {
	border-image: none;
	border: 1px solid transparent;
	background-image: none;
	background-color: transparent;
}

.notebook tab .button:hover {
	color: @theme_fg_color;
	border: 1px solid alpha(black, 0.1);
}

.notebook tab .button:active,
.notebook tab .button:active:hover {
	background-color: alpha(black, 0.08);
	box-shadow: inset 0 1px alpha(black, 0.05);
	color:  @button_active_text;
	icon-shadow: 0 1px @button_active_text_shadow;

	border-color: alpha(black, 0.27) 
		alpha(black, 0.13) 
		alpha(black, 0.13) 
		alpha(black, 0.13);
}

/**************
 * ComboBoxes *
 **************/
GtkComboBox {
	padding: 0;

	-GtkComboBox-arrow-scaling: 0.5;
	-GtkComboBox-shadow-type: none;

	text-shadow: 0 1px @button_text_shadow;
}

GtkComboBox:insensitive {
	text-shadow: none;
	color: @insensitive_fg_color;
}

GtkComboBox .separator {
	/* always disable separators */
	-GtkWidget-wide-separators: true;
	-GtkWidget-horizontal-separator: 0;
	-GtkWidget-vertical-separator: 0;
}

GtkComboBox.combobox-entry .entry:first-child,
GtkComboBox.combobox-entry .button:first-child {
	border-image-width: 3px 0 4px 3px;
	border-radius: 3px 0 0 3px;
	border-right-width: 0;
}

GtkComboBox.combobox-entry .entry:last-child,
GtkComboBox.combobox-entry .button:last-child {
	border-image-width: 3px 3px 4px 0;
	border-radius: 0 3px 3px 0;
	border-left-width: 0;
}

.primary-toolbar GtkComboBox.combobox-entry .entry:first-child,
.primary-toolbar GtkComboBox.combobox-entry .button:first-child {
	border-image-width: 4px 0 4px 4px;
	border-radius: 3px 0 0 3px;
	border-right-width: 0;
}

.primary-toolbar GtkComboBox.combobox-entry .entry:last-child,
.primary-toolbar GtkComboBox.combobox-entry .button:last-child {
	border-image-width: 4px 4px 4px 0;
	border-radius: 0 3px 3px 0;
	border-left-width: 0;
}

GtkComboBox.combobox-entry .entry:focus:first-child {
	box-shadow: inset 1px 2px alpha(@theme_selected_bg_color, 0.1),
		inset 1px 1px alpha(@theme_selected_bg_color, 0.1),
		inset 0 -1px alpha(@theme_selected_bg_color, 0.2);
}

GtkComboBox.combobox-entry .entry:focus:last-child {
	box-shadow: inset -1px 2px alpha(@theme_selected_bg_color, 0.1),
		inset -1px 1px alpha(@theme_selected_bg_color, 0.1),
		inset 0 -1px alpha(@theme_selected_bg_color, 0.2);
}

GtkComboBox.combobox-entry .button:last-child,
GtkComboBox.combobox-entry .button:hover:last-child,
GtkComboBox.combobox-entry .button:active:last-child,
GtkComboBox.combobox-entry .button:hover:active:last-child {
	box-shadow: inset 1px 0 @inset_dark_color, 
		inset 0 1px @entry_inset,
		inset 0 2px alpha(@entry_inset, 0.4);
}

GtkComboBox.combobox-entry .button:first-child,
GtkComboBox.combobox-entry .button:hover:first-child,
GtkComboBox.combobox-entry .button:active:first-child,
GtkComboBox.combobox-entry .button:hover:active:first-child {
	box-shadow: inset -1px 0 @inset_dark_color, 
		inset 0 1px @entry_inset,
		inset 0 2px alpha(@entry_inset, 0.4);
}

GtkComboBox.combobox-entry .button:insensitive:first-child {
	box-shadow: inset -1px 0 @inset_dark_color;
}

GtkComboBox.combobox-entry .button:insensitive:last-child {
	box-shadow: inset 1px 0 @inset_dark_color;
}

GtkComboBox.combobox-entry .button:active,
GtkComboBox.combobox-entry .button:active:hover {
	color: @theme_text_color;
}

GtkComboBox .button {
	color: @theme_text_color;
}

GtkComboBox .button:hover {
	color: @theme_text_color;
}

/**************
 * Scrollbars *
 **************/

.scrollbar {
	background-image: none;
	border-style: solid;
	-GtkRange-trough-border: 0;
	-GtkScrollbar-has-backward-stepper: true;
	-GtkScrollbar-has-forward-stepper: true;
	-GtkRange-stepper-size: 16;
	-GtkRange-slider-width: 13;
	-GtkScrollbar-min-slider-length: 42; /* minimum size for the slider. sadly can't be in '.slider' where it belongs */

	-GtkRange-stepper-spacing: 0;
	-GtkRange-trough-under-steppers: 1;
}

.scrollbars-junction { /* the small square between scrollbars!!! */
	background-image: none;
	background-color: @theme_bg_color;
	border-width: 0;
	border-radius: 0;
	border-image: none;
}

.scrollbar.trough,
.scrollbar.trough.vertical {
	background-image: linear-gradient(to right,
		@scrollbar_trough,
		shade (@scrollbar_trough, 1.08));
	border-left-width: 1px;
	border-style: solid;
	border-color: shade (@theme_bg_color, 0.94);
	border-radius: 0;
	border-image: none;
}

.scrollbar.trough.horizontal {
	background-image: linear-gradient(to bottom,
		@scrollbar_trough,
		shade (@scrollbar_trough, 1.08));
	border-top-width: 1px;
	border-style: solid;
	border-color: shade (@theme_bg_color, 0.94);
	border-radius: 0;
	border-image: none;
}

.scrollbar.button,
.scrollbar.button:active,
.scrollbar.button:active:hover,
.scrollbar.button:insensitive {
	border-style: none;
	border-image: none;
	border-radius: 0;
	background-image: none;
	background-color: transparent;
}

.scrollbar.button:active,
.scrollbar.button:active:hover {
	background-color: alpha(shade(@scrollbar_trough, 0.8), 0.5);
}

.scrollbar.button.top:hover {
	box-shadow: inset 0 -1px mix(@scrollbar_slider, @scrollbar_trough, 0.8);
}

.scrollbar.button.bottom:hover {
	box-shadow: inset 0 1px mix(@scrollbar_slider, @scrollbar_trough, 0.8);
}

.scrollbar.button.right:hover {
	box-shadow: inset 1px 0 mix(@scrollbar_slider, @scrollbar_trough, 0.8);
}

.scrollbar.button.left:hover {
	box-shadow: inset -1px 0 mix(@scrollbar_slider, @scrollbar_trough, 0.8);
}

.scrollbar.button {
	color: @theme_fg_color;
}

.scrollbar.button:hover {
	color: @theme_fg_color;
}

.scrollbar.button:insensitive {
	color: @insensitive_fg_color;
}

.scrollbar.button:active {
	color: @theme_fg_color;
}

.scrollbar.slider.vertical {
	background-image: linear-gradient(to right,
		shade(@scrollbar_slider, 0.95),
		shade(@scrollbar_slider, 0.8));
	border-radius: 20px;
	border-style: solid;
	border-image: none;
	border-color: shade(@scrollbar_slider, 0.65);
	border-width: 1px;
}

.scrollbar.slider.vertical:hover,
.scrollbar.slider.vertical:hover:active {
	background-image: linear-gradient(to right,
		shade(@scrollbar_slider, 0.85),
		shade(@scrollbar_slider, 0.7));
	border-style: solid;
	border-image: none;
	border-color: shade(@scrollbar_slider, 0.65);
	border-width: 1px;
}

.scrollbar.slider.horizontal {
	background-image: linear-gradient(to bottom,
		shade(@scrollbar_slider, 0.95),
		shade(@scrollbar_slider, 0.8));
	border-radius: 20px;
	border-style: solid;
	border-image: none;
	border-color: shade(@scrollbar_slider, 0.65);
	border-width: 1px;
}

.scrollbar.slider.horizontal:hover,
.scrollbar.slider.horizontal:hover:active {
	background-image: linear-gradient(to bottom,
		shade(@scrollbar_slider, 0.85),
		shade(@scrollbar_slider, 0.7));
	border-style: solid;
	border-image: none;
	border-color: shade(@scrollbar_slider, 0.65);
	border-width: 1px;
}

.scrollbar.slider:insensitive {
	background-color: shade(@scrollbar_slider, 0.85);
	border-style: solid;
	border-image: none;
	border-color: shade(@scrollbar_slider, 0.75);
	border-width: 1px;
}

.scrollbar.slider.fine-tune:prelight:active {
	background-image: none;
	border-style: solid;
	border-image: none;
	border-color: transparent;
	border-width: 5px;
}

/*********
 * Menus *
 *********/
/* combobox menus */
GtkTreeMenu.menu {
	background-color: @menu_bg_color;
}

GtkTreeMenu .menuitem {
	padding: 2px;
	border-style: none;
}

/* FIXME: Figure out why menuitem:hover doesn't change anything here */
GtkTreeMenu .menuitem {
	color: @theme_text_color;
}

GtkTreeMenu .menuitem,
.button .menuitem,
.toolbar .button .menuitem {
	text-shadow: none;
}

.context-menu {
	font: initial;
	text-shadow: none;
}

.menu {
	background-color: @menu_bg_color;
	color: @menu_fg_color;
	padding: 0;
	border: 1px solid @borders;
}

.menu.button {
	background-image: none;
	background-color: @theme_base_color;
	color: @internal_element_color;

	border-image: none;
	border-style: none;
}

.menu.button:hover {
	background-image: none;
	background-color: @theme_base_color;
	color: @theme_text_color;

	border-image: none;
	border-style: none;
}

.menu.button:insensitive {
	background-color: @theme_base_color;
	color: lighter(@internal_element_color);

	border-image: none;
	border-style: none;
}

/* this controls the general appearance of the menubar */
.menubar {
	background-image: linear-gradient(to bottom,
		@theme_bg_color,
		shade (@theme_bg_color, 0.96));
	border-width: 0 0 1px 0;
	border-style: solid;
	border-color: alpha (@theme_base_color, 0.2);
	box-shadow: inset 0 -1px shade(@theme_bg_color, 0.92);
	-GtkWidget-window-dragging: true;
}

.menubar .menuitem {
	border-style: none;
	padding: 4px 6px;
	text-shadow: 0 1px @button_text_shadow;
	/*padding: 3px 8px;*/
}

.menubar .menuitem:hover {
	background-image: linear-gradient(to bottom,
		shade (@theme_bg_color, 1.0),
		shade (@theme_bg_color, 0.82));
}

.menubar .menuitem:hover {
	color: @menu_fg_color;
}

.menu .menuitem {
	-GtkMenuItem-arrow-scaling: 0.4;
	padding: 4px;
}

.menu .menuitem:hover {
	border-radius: 0;
}

.menu .menuitem:active,
.menu .menuitem:hover {
	background-color: @theme_selected_bg_color;
	background-image: linear-gradient(to bottom,
		shade (@theme_selected_bg_color, 1.0),
		shade (@theme_selected_bg_color, 0.85));
	text-shadow: none;
}

.menu .menuitem:insensitive {
	background-color: transparent;
}

.menu .menuitem:active,
.menu .menuitem:hover {
	color: @theme_selected_fg_color;
}

.menu .menuitem *:insensitive {
	color: mix (@menu_fg_color, @menu_bg_color, 0.6);
}

.menu .menuitem .accelerator:insensitive {
	color: mix (@menu_fg_color, @menu_bg_color, 0.7);
}

.menuitem .accelerator {
	color: alpha (@menu_fg_color, 0.4);
}

.menuitem .accelerator:hover,
.menuitem .accelerator:active {
	color: alpha (@theme_selected_fg_color, 0.7);
}

GtkModelMenuItem GtkBox GtkImage {
	padding-right: 6px;
}

.menuitem.arrow {
	color: @menu_controls_color;
}

.menuitem.separator {
	color: @menu_separator;

	-GtkMenuItem-horizontal-padding: 0;
}

.menuitem.check,
.menuitem.radio,
.menuitem.check:hover,
.menuitem.radio:hover,
.menuitem.check:insensitive,
.menuitem.radio:insensitive {
	background-image: none;
	background-color: transparent;
}

.menuitem.check:active,
.menuitem.radio:active {
	background-color: transparent;
}

.menuitem.check:active {
	background-image: url("assets/menuitem-checkbox-checked.svg");
}

.menuitem.check:active:hover {
	background-image: url("assets/menuitem-checkbox-checked-selected.svg");
}

.menuitem.check:active:insensitive {
	background-image: url("assets/menuitem-checkbox-checked-insensitive.svg");
}

.menuitem.check:inconsistent,
.menuitem.radio:inconsistent {
	background-image: url("assets/menuitem-checkbox-mixed.svg");
}

.menuitem.check:inconsistent:insensitive,
.menuitem.radio:inconsistent:insensitive {
	background-image: url("assets/menuitem-checkbox-mixed-insensitive.svg");
}

.menuitem.check:inconsistent:hover,
.menuitem.radio:inconsistent:hover {
	background-image: url("assets/menuitem-checkbox-mixed-selected.svg");
}

.menuitem.radio:active {
	background-image: url("assets/menuitem-radio-checked.svg");
}

.menuitem.radio:active:hover {
	background-image: url("assets/menuitem-radio-checked-selected.svg");
}

.menuitem.radio:active:insensitive {
	background-image: url("assets/menuitem-radio-checked-insensitive.svg");
}

/***************
 * Menu Button *
 ***************/
.toolbar GtkMenuButton.button:active,
.toolbar GtkMenuButton.button.raised:active,
GtkMenuButton.button:active,
.linked GtkMenuButton.button:active,
.toolbar .linked.raised GtkMenuButton.button:active,
.toolbar GtkMenuButton.button.linked.raised:active {
/*	background-image: none;
	background-color: @menu_bg_color;

	border-image: none;
	border-color: @menu_bg_color;
	border-radius: 4px 4px 0 0;
	color: @theme_text_color; */
}

GtkMenuButton.button:active,
.linked GtkMenuButton.button:active,
.toolbar .linked.raised GtkMenuButton.button:active,
.toolbar GtkMenuButton.button.linked.raised:active {
	text-shadow: none;
	icon-shadow: none;
}

.linked GtkMenuButton.button:active:last-child,
.toolbar .linked.raised GtkMenuButton.button:active:last-child,
.toolbar GtkMenuButton.button.linked.raised:active:last-child {
	border-top-left-radius: 0;
}

.linked GtkMenuButton.button:active:first-child,
.toolbar .linked.raised GtkMenuButton.button:active:first-child,
.toolbar GtkMenuButton.button.linked.raised:active:first-child {
	border-top-right-radius: 0;
}

.button.menuitem.menubar:active {
	background-image: none;
	background-color: @menu_bg_color;

	border-radius: 4px 4px 0 0;
	border-image: none;
	border-width: 1px 1px 0 1px;
	border-color: @menu_bg_color;
	border-style: solid;
}

.button.menuitem.menubar:active,
GtkMenuButton.button:active,
.toolbar GtkMenuButton.button:active {
	color: @theme_text_color;
}

GtkMenuButton .menu {
	text-shadow: none;
}

/****************
 * Radiobuttons *
 ****************/

.check,
.radio,
.check:insensitive,
.radio:insensitive {
	background-color: transparent;
	border-style: none;
}

GtkCheckButton:hover,
GtkCheckButton:active:hover,
GtkCheckButton:selected,
GtkCheckButton:selected:focus {
	background-color: transparent;
}

/************
 * Toolbars *
 ************/
.toolbar {
	border-style: none;
	border-color: darker (@theme_bg_color);
	padding: 6px;
	background-color: @theme_bg_color;
}

.toolbar .button {
	padding: 1px;
}

.toolbar .button.text-button {
	padding: 2px 16px;
}

.toolbar .button.image-button {
	padding: 5px 4px 4px 5px;
}

.toolbar:insensitive {
	color: alpha (@theme_fg_color, 0.6);
	background-color: @insensitive_bg_color;
}

/********************
 * Menubar Toolbars *
 ********************/
.toolbar.menubar {
	-GtkToolbar-button-relief: normal;
	
	padding: 6px 6px 5px 6px; /* weird padding to compensate border-images
					and eventual top border presence, 
					see selection mode toolbars */

}

/***************
 * Header bars *
 ***************/
.header-bar {
	border-width: 0 0 1px;
	border-style: solid;
	border-color: shade(@borders, 0.90);

	box-shadow: inset 0 -1px shade(@borders, 1.30);
	background-color: @theme_bg_color;

	padding: 6px 6px 5px 6px;
}

.header-bar .button.text-button {
	padding: 2px 16px;
}

.header-bar .button.image-button {
	padding: 5px 4px 5px 5px;
}

.header-bar .title {
	font: Bold 10;
}

.header-bar .subtitle {
	font: 9;
}

/***************
 * Search bars *
 ***************/

.search-bar {
	border-width: 0 0 1px;
	border-style: solid;
	border-color: shade(@borders, 0.90);

	background-color: shade(@theme_bg_color, 0.98);
}

.search-bar .button.close-button {
	padding: 5px 4px 5px 5px;
}

/********************
 * Primary Toolbars *
 ********************/

/* applications using EggEditableToolbar usually set the primary-toolbar
 * hint on the containing vbox, so we need to handle both these cases here.
 */
.primary-toolbar .toolbar,
.primary-toolbar.toolbar {
	border-bottom-color: shade (@theme_bg_color, 0.92);
	border-style: solid;
	border-width: 0 0 1px 0;
	-GtkWidget-window-dragging: true;
	-GtkToolbar-button-relief: normal;
	text-shadow: 0 1px @button_text_shadow;
	padding-top: 3px;
	padding-bottom: 3px;
}

.primary-toolbar .toolbar:insensitive,
.primary-toolbar.toolbar:insensitive {
	background-image: none;
	background-color: shade (@theme_bg_color, 0.97);

	border-color: shade (@theme_bg_color, 0.91);
	text-shadow: none;
}

/* progressbars on primary toolbar entries are special */
.primary-toolbar .toolbar .entry.progressbar,
.primary-toolbar.toolbar .entry.progressbar {
	background-image: linear-gradient(to bottom,
		@trough_bg_color_a,
		@trough_bg_color_b);
	border-width: 1px;
	border-radius: 2px;
	border-style: solid;
	border-color: shade(@internal_element_color, 1.10);
	border-image: none;

	color: @theme_text_color;
}

/*******************
 * Inline toolbars *
 *******************/

.inline-toolbar.toolbar {
	border-width: 1px;
	border-style: solid;
	border-color: @borders;

	-GtkToolbar-button-relief: normal;
	/*box-shadow: inset 0 3px alpha(black, 0.02), inset 0 2px alpha(black, 0.02), inset 0 1px alpha(black, 0.02);*/
	padding: 2px;
}

.inline-toolbar.toolbar:last-child {
	border-top-width: 0;
	/*padding-top: 4px; FIXME: why a specific padding here? */

	border-radius: 0 0 3px 3px;
}

.inline-toolbar.toolbar.vertical:last-child {
	border-left-width: 0;
	/*padding-left: 4px; FIXME: why a specific padding here? */

	border-radius: 0;
}

/***********
 * Sidebar *
 ***********/
.sidebar,
.sidebar .view,
.sidebar GtkScrolledWindow {
	background-color: @sidebar_bg;
}

.sidebar .scrollbar.trough {
	box-shadow: none;
	border-radius: 100px;
	border-style: solid;
	border-width: 2px;
	border-color: transparent;
}

.sidebar .scrollbar.trough {
	background-color: @sidebar_scrollbar_trough;
}

.sidebar .scrollbar.slider {
	background-color: @sidebar_bg;
}

.sidebar .scrollbar.slider:hover {
	background-color: mix (@sidebar_bg, @theme_base_color, 0.35);
}

.sidebar .scrollbar.slider:hover:active {
	background-color: @theme_base_color;
}

.sidebar .radio,
.sidebar .radio:focus,
.sidebar .radio:selected {
	background-image: none;
	background-color: transparent;
}

/*******
 * OSD *
 *******/
.background.osd {
	color: @osd_fg;
	background-color: @osd_bg;
}

GtkOverlay.osd {
	background-color: transparent;
}

.osd.frame {
	background-clip: border-box;
	background-origin: border-box;
}

.osd.button,
.osd.button:active,
.osd .button,
.osd .button:active {
	border-width: 1px;
	border-style: solid;
	border-image: none;
	border-radius: 5px;
}

.osd .button {
	border-color: @osd_button_border;
}

.osd .button:active {
	border-color: @osd_button_border_active;
}

.osd.button,
.osd .button {
	padding: 4px;

	background-image: linear-gradient(to bottom,
		@osd_button_bg_a,
		@osd_button_bg_b 68%,
		@osd_button_bg_c
		);

	color: @osd_button_fg;

	text-shadow: 0 -1px @osd_button_shadow;
	icon-shadow: 0 -1px @osd_button_shadow;
}

.osd.button {
	padding: 8px;
}

.osd.button,
.osd.button:active {
	border-color: transparent;
}

.osd.button,
.osd.button:prelight,
.osd.button:active {
	background-color: shade(@osd_bg, 1.10);
}

.osd .button,
.osd .button:prelight,
.osd .button:active {
	background-color: transparent;
}

.osd.button:insensitive,
.osd .button:insensitive {
	background-image: none;
	background-color: @osd_button_bg_insensitive;
}

.osd.button:active:insensitive,
.osd .button:active:insensitive {
	background-image: none;
	background-color: @osd_button_bg_insensitive_active;
}

.osd.button:hover,
.osd .button:hover {
	color: @osd_button_fg_hover;
}

.osd.button:active,
.osd.button:hover:active,
.osd .button:active,
.osd .button:hover:active {
	color: @osd_button_fg_active;
}

.osd.button:insensitive,
.osd.button:active *:insensitive,
.osd .button:insensitive,
.osd .button:active *:insensitive {
	color: @osd_button_fg_insensitive;
	text-shadow: none;
	icon-shadow: none;
}

.osd.button:hover,
.osd .button:hover {
	background-image: linear-gradient(to bottom,
		@osd_button_bg_hover_a,
		@osd_button_bg_hover_b 68%,
		@osd_button_bg_hover_c
		);
}

.osd.button:active,
.osd.button:active:hover,
.osd .button:active,
.osd .button:active:hover,
.osd GtkMenuButton.button:active {
	background-image: linear-gradient(to bottom,
		@osd_button_bg_active_a,
		@osd_button_bg_active_b 20%,
		@osd_button_bg_active_c
		);
}

.osd GtkMenuButton.button:active {
	background-color: transparent;
	border-color: @osd_button_border;
}

.osd GtkMenuButton.button:active {
	color: @osd_button_fg_active;
	text-shadow: 0 -1px @osd_button_shadow;
}

.osd.toolbar {
	color: @osd_fg;
	text-shadow: 0 1px @osd_text_shadow;

	padding: 10px;
	border-style: none;
	border-radius: 7px;
	background-image: linear-gradient(to bottom,
		@osd_toolbar_bg_a,
		@osd_toolbar_bg_b 63%,
		@osd_toolbar_bg_c
		);
	background-color: transparent;

	-GtkToolbar-button-relief: normal;
}

.osd.toolbar .button {
	padding: 4px;
	border-width: 1px 0;
	border-radius: 0;
	box-shadow: inset -1px 0 @osd_button_inset;
}

.osd.toolbar .button:first-child {
	border-radius: 5px 0 0 5px;
	border-width: 1px 0 1px 1px;
	box-shadow: inset -1px 0 @osd_button_inset;
}

.osd.toolbar .button:last-child {
	box-shadow: none;
	border-radius: 0 5px 5px 0;
	border-width: 1px 1px 1px 0;
}

.osd.toolbar .button:only-child,
.osd.toolbar GtkToolButton .button,
.osd.toolbar GtkToolButton:only-child .button,
.osd.toolbar GtkToolButton:last-child .button,
.osd.toolbar GtkToolButton:first-child .button {
	border-width: 1px;
	border-radius: 5px;
	border-style: solid;

	box-shadow: none;
}

.osd.toolbar .separator {
	color: shade(@osd_lowlight, 0.80);
}

/* used by gnome-settings-daemon's media-keys OSD */
.osd.trough {
	background-color: @osd_trough_bg;
}

.osd.progressbar {
	background-color: @osd_fg;
}

.osd .scale.trough {
	border-color: @osd_button_border;
	background-image: linear-gradient(to bottom,
		shade(@osd_button_border, 0.70),
		shade(@osd_button_border, 0.90)
		);
	background-color: transparent;
}

.osd .scale.trough.highlight {
	border-color: mix(@osd_button_border, @theme_selected_bg_color, 0.70);
	background-image: linear-gradient(to bottom,
		mix(shade(@osd_button_border, 0.55), @theme_selected_bg_color, 0.70),
		mix(shade(@osd_button_border, 0.90), @theme_selected_bg_color, 0.70)
		);
}

.osd .scale.trough:insensitive,
.osd .scale.trough.highlight:insensitive {
	border-color: shade(@osd_button_border, 0.60);
	background-image: none;
	background-color: transparent;
}

.osd GtkProgressBar,
GtkProgressBar.osd {
	padding: 0;
	-GtkProgressBar-xspacing: 0;
	-GtkProgressBar-yspacing: 3px;
	-GtkProgressBar-min-horizontal-bar-height: 3px;
}

.osd GtkProgressBar.trough,
GtkProgressBar.osd.trough {
	padding: 0;
	border-image: none;
	border-style: none;
	border-width: 0;
	background-image: none;
	background-color: transparent;
	border-radius: 0;
}

.osd GtkProgressBar.progressbar,
GtkProgressBar.osd.progressbar {
	border-style: none;
	background-color: @theme_selected_bg_color;
	background-image: none;
	border-radius: 0;	
}

.osd .view,
.osd.view {
	background-color: @osd_view_bg;
}

.osd .scrollbar.trough {
	background-color: @osd_scrollbar_trough;
}

.osd .scrollbar.slider {
	background-color: @osd_scrollbar_slider;
}

.osd .scrollbar.slider:hover {
	background-color: @osd_scrollbar_slider_prelight;
}

.osd .scrollbar.slider:active {
	background-color: @osd_scrollbar_slider_active;
}

.osd GtkIconView.cell:selected,
.osd GtkIconView.cell:selected:focus {
	background-color: transparent;

	border-style: solid;
	border-radius: 15px;
	border-width: 3px;
	border-color: @osd_button_fg;

	outline-color: transparent;
}

/* used by Documents */
.osd .page-thumbnail {
	border-style: solid;
	border-width: 1px;
	border-color: @osd_lowlight;

	/* when there's no pixbuf yet */
	background-color: @osd_bg;
}

/****************************
 * Suggested action buttons *
 ****************************/
.toolbar .suggested-action.button,
.suggested-action.button {
	background-image: linear-gradient(to bottom,
		@suggested_action_button_a,
		@suggested_action_button_b);

	color: @suggested_action_button_fg;
}

.toolbar .suggested-action.button:hover,
.suggested-action.button:hover {
	background-image: linear-gradient(to bottom,
		shade(@suggested_action_button_a, 1.10),
		shade(@suggested_action_button_b, 1.05));
}

.toolbar .suggested-action.button:active,
.toolbar .suggested-action.button:hover:active,
.suggested-action.button:active,
.suggested-action.button:hover:active {
	background-image: linear-gradient(to bottom,
		@suggested_action_button_b,
		@suggested_action_button_a);

	color: @suggested_action_button_fg;
}

.toolbar .suggested-action.button,
.suggested-action.button {
	text-shadow: 0 1px @suggested_action_button_shadow;
	icon-shadow: 0 1px @suggested_action_button_shadow;
}

.toolbar .suggested-action.button:active,
.toolbar .suggested-action.button:hover:active,
.suggested-action.button:active,
.suggested-action.button:hover:active {
	text-shadow: 0 1px shade(@suggested_action_button_shadow, 1.15);
	icon-shadow: 0 1px shade(@suggested_action_button_shadow, 1.15);
}

/******************************
 * Destructive action buttons *
 ******************************/
.destructive-action.button {
	background-image: linear-gradient(to bottom,
		@destructive_action_button_a,
		@destructive_action_button_b);

	color: @destructive_action_button_fg;
}

.destructive-action.button:hover {
	background-image: linear-gradient(to bottom,
		shade(@destructive_action_button_a, 1.10),
		shade(@destructive_action_button_b, 1.05));
}

.destructive-action.button:active,
.destructive-action.button:hover:active {
	background-image: linear-gradient(to bottom,
		@destructive_action_button_b,
		@destructive_action_button_a);

	color: @destructive_action_button_fg;
}

.destructive-action.button {
	text-shadow: 0 1px @destructive_action_button_shadow;
	icon-shadow: 0 1px @destructive_action_button_shadow;
}

.destructive-action.button:active,
.destructive-action.button:hover:active {
	text-shadow: 0 1px shade(@destructive_action_button_shadow, 1.15);
	icon-shadow: 0 1px shade(@destructive_action_button_shadow, 1.15);
}

/**************************
 * Selection Mode classes *
 **************************/
.selection-mode.header-bar,
.selection-mode.toolbar {
	color: @selection_toolbar_fg;
	background-image: linear-gradient(to bottom,
		@selection_toolbar_bg_a,
		@selection_toolbar_bg_b);
	background-color: transparent;

	border-color: @borders;
	border-style: solid;
	border-image: none;

	text-shadow: 0 1px @selection_toolbar_shadow;
}

.selection-mode.header-bar {
	border-top-color: @selection_toolbar_bg_a;
	border-bottom-color: @selection_toolbar_border;

	box-shadow: inset 0 -1px shade(@selection_toolbar_border, 1.20);
}

.selection-mode.toolbar {
	padding: 6px;
}

/* regular button */
.selection-mode.header-bar .button,
.selection-mode.toolbar .button,
.selection-mode.toolbar GtkToolButton .button {
	background-image: linear-gradient(to bottom,
		@selection_toolbar_button_a,
		@selection_toolbar_button_b);

	border-image: none;
	border-color: @selection_toolbar_button_border;
	border-width: 1px;

	box-shadow: inset 0 1px alpha(white, 0.1);

	color: @selection_toolbar_button_fg;
}

.selection-mode.header-bar .button:hover,
.selection-mode.toolbar .button:hover,
.selection-mode.toolbar GtkToolButton .button:hover {
	background-image: linear-gradient(to bottom,
		shade(@selection_toolbar_button_a, 1.05),
		shade(@selection_toolbar_button_b, 1.02));
}

.selection-mode.header-bar .button:active,
.selection-mode.header-bar .button:hover:active,
.selection-mode.toolbar .button:active,
.selection-mode.toolbar .button:hover:active,
.selection-mode.toolbar GtkToolButton .button:active,
.selection-mode.toolbar GtkToolButton .button:hover:active {
	background-image: linear-gradient(to bottom,
		shade(@selection_toolbar_button_b, 0.95),
		shade(@selection_toolbar_button_a, 0.88));
	box-shadow: none;
}

.selection-mode.header-bar .button:active,
.selection-mode.toolbar .button:active,
.selection-mode.toolbar GtkToolButton .button:active {
	color: @selection_toolbar_button_fg;
}

.selection-mode.header-bar .button,
.selection-mode.header-bar .button:active,
.selection-mode.toolbar .button,
.selection-mode.toolbar .button:active,
.selection-mode.toolbar GtkToolButton .button,
.selection-mode.toolbar GtkToolButton .button:active {
	text-shadow: 0 1px @selection_toolbar_button_shadow;
	icon-shadow: 0 1px @selection_toolbar_button_shadow;
}

/* suggested button */
.selection-mode.header-bar .suggested-action.button,
.selection-mode.toolbar .suggested-action.button,
.selection-mode.toolbar GtkToolButton.suggested-action .button {
	background-image: linear-gradient(to bottom,
		@selection_toolbar_suggested_button_a,
		@selection_toolbar_suggested_button_b 40%,
		@selection_toolbar_suggested_button_c);

	border-image: none;
	border-color: @selection_toolbar_suggested_button_border;
	border-width: 1px;

	box-shadow: inset 0 2px alpha(@selection_toolbar_suggested_button_b, 0.2),
		inset 0 1px @selection_toolbar_suggested_button_a;
	color: @theme_text_color;
}

.selection-mode.header-bar .suggested-action.button:hover,
.selection-mode.toolbar .suggested-action.button:hover,
.selection-mode.toolbar GtkToolButton.suggested-action .button:hover {
	background-image: linear-gradient(to bottom,
		shade(@selection_toolbar_suggested_button_a, 1.15),
		shade(@selection_toolbar_suggested_button_b, 1.15) 40%,
		@selection_toolbar_suggested_button_c);
}

.selection-mode.header-bar .suggested-action.button:active,
.selection-mode.header-bar .suggested-action.button:hover:active,
.selection-mode.toolbar .suggested-action.button:active,
.selection-mode.toolbar .suggested-action.button:hover:active,
.selection-mode.toolbar GtkToolButton.suggested-action .button:active,
.selection-mode.toolbar GtkToolButton.suggested-action .button:hover:active {
	background-image: linear-gradient(to bottom,
		shade(@selection_toolbar_suggested_button_c, 0.92),
		@selection_toolbar_suggested_button_b 40%,
		shade(@selection_toolbar_suggested_button_a, 0.92));
	box-shadow: none;
}

.selection-mode.header-bar .suggested-action.button:active,
.selection-mode.toolbar .suggested-action.button:active,
.selection-mode.toolbar GtkToolButton.suggested-action:active {
	color: @theme_text_color;
}

.selection-mode.header-bar .suggested-action.button,
.selection-mode.header-bar .suggested-action.button:active,
.selection-mode.toolbar .suggested-action.button,
.selection-mode.toolbar .suggested-action.button:active,
.selection-mode.toolbar GtkToolButton.suggested-action .button,
.selection-mode.toolbar GtkToolButton.suggested-action:active {
	text-shadow: 0 1px @button_text_shadow;
	icon-shadow: 0 1px @button_text_shadow;
}

/* menu button */
.selection-mode.header-bar .selection-menu.button,
.selection-mode.toolbar .selection-menu.button {
	background-image: none;
	border-image: none;
	border-color: transparent;
	border: 0px;
	box-shadow: none;

	color: @selection_menu_fg;
}

.selection-mode.toolbar .dim-label,
.selection-mode.toolbar .selection-menu.button .dim-label {
	color: @selection_menu_fg;
}

.selection-mode.header-bar .selection-menu.button:hover,
.selection-mode.toolbar .dim-label:hover,
.selection-mode.toolbar .selection-menu.button:hover,
.selection-mode.toolbar .selection-menu.button .dim-label:hover {
	background-color: transparent;
	color: @selection_menu_hover;
}

.selection-mode.header-bar .selection-menu.button:active,
.selection-mode.toolbar .selection-menu.button:active {
	border-color: transparent;
	border-radius: 3px;
	border-width: 1px;

	background-color: transparent;
}

.selection-mode.header-bar .selection-menu.button:active,
.selection-mode.toolbar .selection-menu.button:active {
	color: @selection_menu_active;
}

.selection-mode.header-bar .selection-menu.button,
.selection-mode.toolbar .selection-menu.button {
	text-shadow: 0 1px @selection_toolbar_shadow;
}

.selection-mode.header-bar .selection-menu.button .menuitem,
.selection-mode.toolbar .selection-menu.button .menuitem {
	text-shadow: none;
}

/****************
 * GtkAssistant *
 ****************/
GtkAssistant .sidebar .highlight {
	background-color: transparent;
	color: @theme_fg_color;
	font: bold;
}

GtkAssistant .sidebar {
	padding: 12px;

	border-width: 1px;
	border-radius: 2px;
	border-style: solid;
	border-color: @inactive_frame_color;

	color: mix (@theme_fg_color, @theme_bg_color, 0.40);

	background-color: shade (@theme_bg_color, 0.97);
	/* shall we make it like sidebars in general? */

}

/*************
 * GtkSwitch *
 *************/

GtkSwitch {
	border-radius: 8px;
	padding: 2px;
	background-color: transparent;
}

GtkSwitch.trough,
GtkSwitch.trough:insensitive {
	border: none;
	border-image: none;
	color: transparent;
	box-shadow: none;
	background-color: transparent;
	background-size: 48px 26px;
	background-position: center center;
	background-repeat: no-repeat;
	text-shadow: none;
}

GtkSwitch.slider {
	background-color: transparent;
	border: none;
	border-image: none;
}

/***********************
 * Tree and Icon views *
 ***********************/
GtkTreeView {
	-GtkTreeView-vertical-separator: 0;

	-GtkWidget-focus-line-width: 1;
	-GtkWidget-focus-padding: 1;

	outline-color: alpha(@theme_text_color, 0.6);
}

GtkTreeView.dnd {
	border-color: @internal_element_color;
	border-radius: 2px;
	border-width: 1px;
	border-style: solid;
}

GtkTreeView:selected:focus {
	outline-color: mix(@theme_selected_fg_color, @theme_selected_bg_color, 0.30);
}

GtkIconView.cell:selected,
GtkIconView.cell:selected:focus {
	border-radius: 4px;

	/* FIXME: this probably needs to be better;
	 * see https://bugzilla.gnome.org/show_bug.cgi?id=644157
	 */
	outline-color: @treeview_focus_border;
	outline-style: solid;
	outline-offset: 3px;
}

.view {
	background-color: @theme_base_color;
	color: @theme_text_color;
}

.view:insensitive {
	background-color: @insensitive_bg_color;
	color: @insensitive_fg_color;
}

.view:selected {
	background-color: @theme_selected_bg_color;
	color: @theme_selected_fg_color;
}

.view:selected:backdrop {
	background-color: shade(@theme_unfocused_bg_color, 0.94);
	color: @theme_fg_color;
}

.cell {
	color: @theme_text_color;
	padding: 2px;
	text-shadow: none;
}

.cell:selected,
.cell:selected:focus {
	background-color: @theme_selected_bg_color;
	color: @theme_selected_fg_color;
}

.cell:selected:backdrop,
.cell:selected:focus:backdrop {
	background-color: shade(@theme_unfocused_bg_color, 0.94);
	color: @theme_fg_color;
}

row:selected,
row:selected:focus {
	border-width: 1px 0 0 0;
	border-style: solid;
	border-color: shade (@theme_selected_bg_color, 0.85);
	background-image: linear-gradient(to bottom,
		shade (@theme_selected_bg_color, 1.0),
		shade (@theme_selected_bg_color, 0.85));
	box-shadow: none;
}

row:selected:backdrop,
row:selected:focus:backdrop {
	border-width: 1px 0 1px 0;
	border-style: solid;
	border-color: shade (@theme_bg_color, 0.85);
	background-image: linear-gradient(to bottom,
		shade (@theme_bg_color, 1.0),
		shade (@theme_bg_color, 0.85));
	color: @theme_fg_color;
	text-shadow: none;
	box-shadow: none;
}

GtkTreeView row:nth-child(even),
GtkTreeView row:nth-child(odd) {
	background-color: shade (@theme_base_color, 1.0);
	box-shadow: inset 0 -1px 0 0 alpha (@theme_bg_color, 0.4);
}

GtkTreeView row:nth-child(odd):hover,
GtkTreeView row:nth-child(even):hover {
	background-color: shade (@theme_selected_bg_color, 1.55);
}

GtkTreeView row:nth-child(odd):backdrop:hover,
GtkTreeView row:nth-child(even):backdrop:hover {
	background-color: shade (@theme_base_color, 0.96);
}

column-header.button,
column-header .button {
	color: @theme_fg_color;
}

column-header.button,
column-header .button,
column-header.button:insensitive,
column-header .button:insensitive,
column-header.button:hover,
column-header .button:hover {
	background-image: none;
	padding: 0 4px;
	text-shadow: none;
	icon-shadow: none;
	border-radius: 0;
}

column-header.button:insensitive,
column-header .button:insensitive {
	background-color: @insensitive_bg_color;
}

column-header.button:active,
column-header .button:active,
column-header.button:active:hover,
column-header .button:active:hover {
	color: @theme_fg_color;
	text-shadow: none;
	icon-shadow: none;
	border-radius: 0;
}

column-header .button.dnd {
	background-color: transparent;
	background-image: linear-gradient(to bottom,
		shade(@theme_base_color, 0.97),
		@theme_base_color);
	border-width: 0 1px;
	border-image-slice: 0 1;
}

.expander {
	color: @theme_fg_color;
	border-color: @theme_fg_color;
}

.expander:active {
	color: @theme_fg_color;
	border-color: @theme_fg_color;
}

.expander:hover {
	color: @internal_element_color;
	border-color: @internal_element_color;
}

.expander row:selected,
.expander row:selected:focus {
	color: @expander_row_selected_color;
	border-color: @expander_row_selected_color;
	border-width: 0;
	background-color: transparent;
	background-image: none;
	border-image: none;
	box-shadow: none;
}

.expander row:selected:hover,
.expander row:selected:focus:hover {
	color: @theme_selected_fg_color;
	border-color: @theme_selected_fg_color;
}

/**************
 * List boxes *
 **************/
EggListBox {
	background-color: @list_box_bg;
}

EggListBox:hover {
	background-color: @content_view_bg;
}

EggListBox:selected {
	background-color: @theme_selected_bg_color;
}

.list {
	background-color: @list_box_bg;
}

.list-row:hover {
	background-color: @content_view_bg;
}

.list-row:selected {
	background-color: @theme_selected_bg_color;
}

/****************
 * Content view *
 ****************/
.content-view.view {
	background-color: @content_view_bg;
}

.content-view.view:insensitive {
	background-color: @theme_unfocused_base_color;
	background-image: none;
}

.content-view.view:selected {
	background-color: @theme_selected_bg_color;
	background-image: none;
}

/* FIXME: EggListBox should set the .cell style class on
 * the background it renders for the children, like
 * GtkIconView and GtkTreeView do */
.content-view.cell {
	background-color: transparent;
	background-image: none;
}

EggListBox.content-view:hover,
.content-view.cell:hover {
	background-color: @theme_bg_color;
}

EggListBox.content-view:selected,
EggListBox.content-view:active,
.content-view.cell:selected,
.content-view.cell:active {
	background-color: @theme_selected_bg_color;
	background-image: none;
}

GdMainIconView.content-view {
	-GdMainIconView-icon-size: 40;
}

GtkIconView.content-view.cell.check {
	background-image: url("assets/grid-selection-unchecked.svg");
	background-color: transparent;
}

GtkIconView.content-view.cell.check:active {
	background-image: url("assets/grid-selection-checked.svg");
	background-color: transparent;
}

/* Make spinner visible on both dark and bright backgrounds w/o making
 * it look ugly/weird.
 */
GdMainIconView.content-view.cell:active {
	color: gray;
}

.content-view.view.check,
.content-view.view.check:active {
	background-color: transparent;
}

GtkIconView.content-view.check:hover,
GtkIconView.content-view.check:insensitive,
GtkIconView.content-view.check:selected {
	background-color: transparent;
}

/* used by Documents and Evince */
.content-view.document-page {
	border-style: solid;
	border-width: 3px 3px 6px 4px;
	border-image: url("assets/thumbnail-frame.png") 3 3 6 4;
}

/*********************
 * App Notifications *
 *********************/
.app-notification {
	border-style: solid;
	border-color: @app_notification_border;
	border-width: 0 1px 1px 1px;
	border-radius: 0 0 5px 5px;
	padding: 8px;

	background-image: linear-gradient(to bottom,
		@app_notification_a,
		@app_notification_b 18%,
		@app_notification_c);

	color: @theme_text_color;
	text-shadow: 0 1px @primary_toolbar_button_text_shadow;
}

/* Calendars */
GtkCalendar {
	padding: 2px;
}

GtkCalendar.view {
	border-radius: 3px;
	border-style: solid;
	border-width: 1px;
	padding: 2px;
}

GtkCalendar.header {
	border-radius: 0;
	background-image: linear-gradient(to bottom,
		shade(@theme_bg_color, 1.04),
		shade(@theme_bg_color, 0.89));
	border-width: 0;
}

GtkCalendar.button,
GtkCalendar.button:insensitive {
	background-image: none;
	background-color: transparent;
}

.highlight,
GtkCalendar.highlight {
	background-color: @theme_selected_bg_color;
	color: @theme_selected_fg_color;
	border-radius: 0;
	padding: 0;
	border-width: 0;
}

/**************
 * GtkInfoBar *
 **************/
GtkInfoBar {
	border-width: 0;
	border-style: none;
}

.info,
.question,
.warning,
.error {
	background-color: @infobar_bg_color;
	color: @infobar_fg_color;
	text-shadow: 0 1px @infobar_text_shadow;
	border-color: darker(@infobar_bg_color);
}

.info .button.close,
.warning .button.close,
.question .button.close,
.error .button.close {
	color: @infobar_fg_color;
	icon-shadow: 0 1px @infobar_text_shadow;
}

.info .button.close:hover,
.warning .button.close:hover,
.question .button.close:hover,
.error .button.close:hover {
	background-image: linear-gradient(to bottom,
		alpha(white, 0.3),
		alpha(white, 0.2) 30%,
		alpha(black, 0.02));
}

.info .button.close:active,
.warning .button.close:active,
.question .button.close:active,
.error .button.close:active {
	color: @infobar_fg_color;
	background-image: linear-gradient(to bottom,
		alpha(black, 0.1),
		transparent);
}

.info .entry,
.info .entry:focus,
.info .button,
.info .button:insensitive,
.info .button:active,
.warning .entry,
.warning .entry:focus,
.warning .button,
.warning .button:insensitive,
.warning .button:active,
.error .entry,
.error .entry:focus,
.error .button,
.error .button:insensitive,
.error .button:active,
.question .entry,
.question .entry:focus,
.question .button,
.question .button:insensitive,
.question .button:active {
	border-image: none;

	color: @theme_fg_color;
	border-color: darker(@infobar_bg_color);
	border-style: solid;
	border-width: 1px;
}

/**************
 * Dim labels *
 **************/
.view.dim-label,
.dim-label {
	color: alpha(currentColor, 0.55);
	text-shadow: none;
}

/*************************
 * Touch text selections *
 *************************/
GtkBubbleWindow {
	border-radius: 5px;
	background-clip: border-box;
}

GtkBubbleWindow.osd.background {
	background-color: @osd_popover_bg;
}

GtkBubbleWindow .toolbar {
	background-color: transparent;
}

/*******
 * CSD *
 *******/
.titlebar {
	text-shadow: 0 1px @wm_title_shadow;

	background-image: linear-gradient(to bottom,
		@wm_bg_a,
		@wm_bg_b);
	border-radius: 6px 6px 0px 0px;
}

.tiled .titlebar {
	border-radius: 0;
}

.maximized .titlebar {
	border-radius: 0;
}

/* this is the default titlebar that is added by GTK
 * when client-side decorations are in use and the application
 * did not set a custom titlebar.
 */
.titlebar.default-decoration {
	border: none;
	box-shadow: none;
}

.titlebar .title {
	font: Bold 10;
}

.titlebar:backdrop {
	text-shadow: none;
	background-image: none;
	background-color: @wm_bg_b;
}

.titlebar .titlebutton {
	icon-shadow: 0px 1px @wm_title_shadow;
	color: @wm_title;
	background: none;
	padding: 5px 5px 6px 5px;

	border-radius: 4px;
	border-width: 2px;
	border-color: transparent;
	border-style: solid;
	border-image: none;
}

.titlebar .titlebutton:hover {
	background-image: linear-gradient(to bottom,
		@button_hover_gradient_color_a,
		@button_hover_gradient_color_b);
}

.titlebar .titlebutton:active {
	background-image: linear-gradient(to bottom,
		@borders,
		shade(@theme_bg_color, 0.95));
	color: @theme_selected_fg_color;
	icon-shadow: none;
}

.titlebar .right .titlebutton:first-child {
/*	border-left: 1px solid @menu_separator; */
}

.titlebar .right .titlebutton:last-child {

}

.titlebar .left .titlebutton:last-child {
/*	border-right: 1px solid @menu_separator; */
}

.titlebar .left .titlebutton:first-child {

}

.titlebar .titlebutton:backdrop {
	background-image: none;
	color: @wm_unfocused_title;
	icon-shadow: none;
}

.window-frame {
	border-color: darker(@theme_bg_color);
	border-radius: 6px 6px 0 0;
	border-width: 1px;
	border-style: solid;

	box-shadow: 0 2px 8px 3px @wm_shadow;

	/* this is used for the resize cursor area */
	margin: 10px;
}

.window-frame.tiled {
	border-radius: 0;
	background-color: @theme_bg_color;
}

.window-frame:backdrop {
	box-shadow: 0 2px 5px 1px @wm_shadow;
}

/**********************
 * Fallback Mode Panel
 **********************/

.gnome-panel-menu-bar,
PanelApplet > GtkMenuBar.menubar,
PanelToplevel,
PanelWidget,
PanelAppletFrame,
PanelApplet {
	background-color: @os_chrome_bg_color;
	background-image: none;
	color: @os_chrome_fg_color;
}

ClockBox,
.gnome-panel-menu-bar.menubar,
PanelApplet > GtkMenuBar.menubar {
	font: bold;
}

.gnome-panel-menu-bar.menubar .menuitem:hover,
PanelApplet > GtkMenuBar.menubar .menuitem:hover {
	text-shadow: 0 1px @os_chrome_bg_color;
}

.gnome-panel-menu-bar.menubar .menu,
PanelApplet > GtkMenuBar.menubar .menu {
	font: regular;
}

.gnome-panel-menu-bar.menubar .menu:hover,
PanelApplet > GtkMenuBar.menubar .menu:hover {
	text-shadow: none;
}

.gnome-panel-menu-bar .menuitem:hover,
PanelApplet > GtkMenuBar.menubar .menuitem:hover,
.gnome-panel-menu-bar .menuitem:hover,
PanelApplet > GtkMenuBar.menubar .menuitem:hover {
	background-color: @os_chrome_selected_bg_color;
	color: @os_chrome_selected_fg_color;
}

.gnome-panel-menu-bar .menuitem:hover,
PanelApplet > GtkMenuBar.menubar .menuitem:hover {
	color: @os_chrome_selected_fg_color;
}

PanelApplet .button,
PanelApplet .button:hover {
	padding: 4px;

	border-image: none;
	border-width: 0;
	border-radius: 0;

	background-image: none;
	background-color: @os_chrome_bg_color;

	color: @os_chrome_fg_color;
	text-shadow: none;
}

PanelApplet .button:active:hover,
PanelApplet .button:active {
	border-image: none;
	background-image: none;
	background-color: @os_chrome_selected_bg_color;
	border-width: 0;
	border-radius: 0;
}

PanelApplet:hover {
	color: @os_chrome_selected_fg_color;
}

PanelApplet:active,
PanelApplet:hover:active {
	color: @os_chrome_selected_fg_color;
	text-shadow: 0 1px @os_chrome_bg_color;
}

/* Fixes the indicator applet text */
PanelApplet > GtkMenuBar > GtkMenuItem > GtkBox > GtkLabel {
	color: @os_chrome_fg_color;
	text-shadow: none;
	border-image: none;
}

WnckPager {
	background-color: lighter(@os_chrome_selected_bg_color);
}

NaTrayApplet {
	-NaTrayApplet-icon-padding: 12;
	-NaTrayApplet-icon-size: 16;
}

GsmFailWhaleDialog {
	background-color: @os_chrome_bg_color;
	background-image: none;
	color: @os_chrome_fg_color;
}

GsmFailWhaleDialog .button,
GsmFailWhaleDialog .button:active {
	border-image: none;
	border-color: @borders;
	border-width: 1px;
}

