/* Button background */
.button,
.toolbar .button.raised,
.toolbar .raised .button,
.toolbar GtkComboBox .button,
.spinbutton.vertical .button {
	background-image: linear-gradient(to bottom, 
		@button_gradient_color_a,
		@button_gradient_color_b);
	background-color: transparent;
}

/* Pushed button and progressbar through background */
.button:active, 
.spinbutton.vertical .button:active,
.toolbar .button:active,
.toolbar .button.raised:active,
.toolbar .raised .button:active {
	background-image: linear-gradient(to bottom,
		@button_active_gradient_color_a,
		@button_active_gradient_color_b);
	background-color: transparent; 
}

.trough,
.trough.highlight,
.trough row {
	background-image: linear-gradient(to bottom,
		@trough_bg_color_a,
		@trough_bg_color_b);
	background-color: transparent; 
}

.button:active:hover,
.spinbutton.vertical .button:active:hover,
.toolbar .button:active:hover,
.toolbar .button.raised:active:hover,
.toolbar .raised .button:active:hover,
.trough row:hover {
	background-image: linear-gradient(to bottom,
		shade (@button_active_gradient_color_a, 1.05),
		shade (@button_active_gradient_color_b, 1.05));
	background-color: transparent; 
}

/* Flipped pushed button background for vertical progressbar through and the like */
.trough.vertical {
	background-image: linear-gradient(to right,
		@trough_bg_color_a,
		@trough_bg_color_b);
}

/* Primary and inline toolbars pushed button background */
.primary-toolbar .button:active,
.inline-toolbar .button:active {
	background-image: linear-gradient(to bottom,
		@button_active_gradient_color_a,
		@button_active_gradient_color_b);
	background-color: transparent;
}

.primary-toolbar .button:active:hover,
.inline-toolbar .button:active:hover {
	background-image: linear-gradient(to bottom,
		shade (@button_active_gradient_color_a, 1.05),
		shade (@button_active_gradient_color_b, 1.05));
	background-color: transparent;
}

/* Prelit button background */
.button:hover,
.toolbar .button:hover,
.toolbar .button.raised:hover,
.toolbar .raised .button:hover,
.toolbar GtkComboBox .button:hover,
.spinbutton.vertical .button:hover {
	background-color: transparent;
	background-image: linear-gradient(to bottom,
		@button_hover_gradient_color_a,
		@button_hover_gradient_color_b);
}

/* Prelit button on primary toolbar background */
.primary-toolbar .button:hover {
	background-color: transparent;
	background-image: linear-gradient(to bottom,
		@button_gradient_color_a,
		@button_gradient_color_b);
}

/* Insensitive button background */
.button:insensitive,
.spinbutton.vertical .button:insensitive,
.toolbar GtkComboBox .button:insensitive,
.toolbar .button.raised:insensitive,
.toolbar .raised .button:insensitive {
	background-image: none;
	background-color: @insensitive_bg_color;
}

/* Pushed + Insensitive button background */
.button:active:insensitive,
.toolbar .button:active:insensitive,
.toolbar GtkComboBox .button:active:insensitive {
	background-image: linear-gradient(to bottom,
		shade(@insensitive_bg_color, 0.95),
		@insensitive_bg_color 40%,
		@insensitive_bg_color);
	background-color: transparent;
}

/* Entry background */
.entry,
GtkComboBox.combobox-entry .button,
GtkComboBox.combobox-entry .button:hover,
.primary-toolbar GtkComboBox.combobox-entry .button,
.primary-toolbar GtkComboBox.combobox-entry .button:hover,
.level-bar.trough {
	background-image: linear-gradient(to bottom,
		@entry_background_a,
		@entry_background_b);
	box-shadow: inset 0 1px @entry_inset, 
		inset 0 2px alpha(@entry_inset, 0.4);
}

/* Entry pushed button background */
.primary-toolbar GtkComboBox.combobox-entry .button:active,
/* .primary-toolbar GtkComboBox.combobox-entry .button:hover:active,*/
GtkComboBox.combobox-entry .button:active,
.spinbutton .button:active,
.spinbutton .button:active:hover {
	background-image: linear-gradient(to bottom,
		shade(@entry_background_a, 0.9),
		@entry_background_b);
	background-color: transparent;
	box-shadow: inset 0 1px @entry_inset, 
		inset 0 2px alpha(@entry_inset, 0.4);
}

column-header.button,
column-header .button {
	background-image: linear-gradient(to bottom,
		shade(@entry_background_a, 0.94),
		@entry_background_b);
	box-shadow: inset 0 1px @entry_inset, 
		inset 0 2px alpha(@entry_inset, 0.4);
}

column-header.button:hover,
column-header .button:hover {
	background-image: linear-gradient(to bottom,
		shade(@entry_background_a, 1.0),
		@entry_background_b);
	box-shadow: inset 0 1px @entry_inset, 
		inset 0 2px alpha(@entry_inset, 0.4);
}

column-header.button:active,
column-header .button:active,
column-header.button:active:hover,
column-header .button:active:hover {
	background-image: linear-gradient(to bottom,
		shade(@entry_background_a, 0.9),
		@entry_background_b);
	background-color: transparent;
	box-shadow: inset 0 1px @entry_inset, 
		inset 0 2px alpha(@entry_inset, 0.4);
}

/* Insensitive entry background */
.entry:insensitive,
GtkComboBox.combobox-entry .button:insensitive,
.level-bar.trough:insensitive {
	background-color: @insensitive_bg_color;
	background-image: none;
	box-shadow: none;
}

/* Primary and inline toolbars background */
.primary-toolbar .toolbar,
.primary-toolbar.toolbar,
.inline-toolbar.toolbar  {
	background-image: linear-gradient(to bottom,
		shade (@theme_bg_color, 1.0),
		shade (@theme_bg_color, 0.96));
	background-color: transparent;
}

.primary-toolbar .toolbar.vertical,
.primary-toolbar.toolbar.vertical,
.inline-toolbar.toolbar.vertical {
	background-image: linear-gradient(to right,
		shade (@theme_bg_color, 1.0),
		shade (@theme_bg_color, 0.96));
	background-color: transparent;
}

.scale.trough {
	background-image: linear-gradient(to bottom,
		@scale_trough_bg_a,
		@scale_trough_bg_b);
}

.scale.trough.vertical {
	background-image: linear-gradient(to right,
		@scale_trough_bg_a,
		@scale_trough_bg_b);
}

/* Active switch background*/
GtkSwitch.trough:active,
.scale.progressbar {
	background-image: linear-gradient(to bottom,
		@switch_trough_active_bg_a,
		@switch_trough_active_bg_b);
	background-color: transparent;
}

.scale.progressbar.vertical {
	background-image: linear-gradient(to right,
		@switch_trough_active_bg_a,
		@switch_trough_active_bg_b);
	background-color: transparent;
}

/* Progressbar backgrounds */

.progressbar,
.progressbar row,
.progressbar row:hover,
.progressbar row:selected,
.progressbar row:selected:focus {
	background-image: linear-gradient(to left top,
		alpha (@progressbar_pattern, 0.25),
		alpha (@progressbar_pattern, 0.25) 25%,
		transparent 25%,
		transparent 50%,
		alpha (@progressbar_pattern, 0.25) 50%,
		alpha (@progressbar_pattern, 0.25) 75%,
		transparent 75%,
		transparent),
		linear-gradient(to bottom,
		@progressbar_background_a,
		@progressbar_background_b);
	background-size: 40px 40px, auto;
	box-shadow: inset 1px 1px alpha(white, 0.2), inset -1px -1px alpha(white, 0.1);
}

.progressbar.vertical {
	background-image: linear-gradient(to right top,
		alpha (@progressbar_pattern, 0.25),
		alpha (@progressbar_pattern, 0.25) 25%,
		transparent 25%,
		transparent 50%,
		alpha (@progressbar_pattern, 0.25) 50%,
		alpha (@progressbar_pattern, 0.25) 75%,
		transparent 75%,
		transparent),
		linear-gradient(to right,
		@progressbar_background_a,
		@progressbar_background_b);
}
