/* Default color scheme */

@define-color base_color #E9EFE7; /* used by some apps */
@define-color bg_color #E9EFE7;
@define-color text_color #000000;
@define-color fg_color #000000;
@define-color selected_bg_color #70816A;
@define-color selected_fg_color #ffffff;

@define-color tooltip_bg_color #000000; /*#343434;*/
@define-color tooltip_fg_color #ffffff;

@define-color theme_base_color @base_color;
@define-color theme_bg_color @bg_color;
@define-color theme_text_color @text_color;
@define-color theme_fg_color @fg_color;
@define-color theme_selected_bg_color @selected_bg_color; /* = shade(@bg_color, 0.5)*/
@define-color theme_selected_fg_color @selected_fg_color;

@define-color theme_tooltip_bg_color @tooltip_bg_color;
@define-color theme_tooltip_fg_color @tooltip_fg_color;

@define-color theme_main_color #ffffff;

@define-color keyboard_focus_border shade(@bg_color, 0.8);

@define-color button_gradient_color_a shade(@theme_bg_color, 1.4);
@define-color button_gradient_color_b shade(@theme_bg_color, 0.75);
@define-color button_border #AAABA9;

@define-color button_hover_gradient_color_a shade(@theme_bg_color, 1.1);
@define-color button_hover_gradient_color_b shade(@theme_bg_color, 0.9);

@define-color insensitive_bg_color #E0E6DE;
@define-color insensitive_fg_color #AAABA9;
@define-color insensitive_border_color alpha(#ababab, 0.5);

@define-color trough_bg_color_a #C8CCC7;
@define-color trough_bg_color_b #E2E4E1;

@define-color active_switch_bg_color_a #57704F;
@define-color active_switch_bg_color_b #70CB52; /*#BB9B7D*/

@define-color switch_slider_color @button_gradient_color_b;
@define-color switch_slider_border #5D8051;

@define-color progressbar_background_a #ffffff;
@define-color progressbar_background_b #BEC8BB;
@define-color progressbar_border #a1a1a1;
@define-color progressbar_pattern #A0A19F;

@define-color scale_fill_a #A1AF9C;
@define-color scale_fill_b #70816A;

/*@define-color menu_color #655b56;*/
@define-color menu_controls_color #ffffff;

@define-color highlighted_border #8E8F8E;
@define-color internal_element_color #898A89;

@define-color notebook_border alpha(@frame_color, 0.6); /*#aeaaa6;*/
@define-color notebook_active_tab_border alpha(@frame_color, 0.6); /*#a6a29e; #9b9b9b;*/
/*@define-color notebook_selected_tab_color #a38972;*/

@define-color toolbar_gradient_base #D4DFD1;

@define-color treeview_odd_row #F8FAF7;
@define-color treeview_even_row @bg_color;

@define-color expander_row_selected_color #DFF0D9; /*#acccee*/

@define-color borders #AAABA9;

@define-color link_color #4a90d9;
@define-color frame_color #9FA09E;
@define-color inactive_frame_color #cacaca;
@define-color warning_color #f57900;
@define-color error_color #cc0000;
@define-color success_color #4e9a06;

@define-color info_fg_color rgb (51, 51, 38);
@define-color info_bg_color rgb (252, 252, 189);
@define-color warning_fg_color rgb (51, 35, 12);
@define-color warning_bg_color rgb (250, 173, 61);
@define-color question_fg_color rgb (255, 255, 255);
@define-color question_bg_color rgb (13, 92, 179);
@define-color error_fg_color rgb (255, 255, 255);
@define-color error_bg_color rgb (191, 44, 44);

@define-color focus_border shade(@bg_color, 0.7);

@define-color theme_unfocused_base_color shade(@insensitive_bg_color, 1.015);

@define-color wm_a shade(@theme_bg_color, 1.3);
@define-color wm_b @theme_bg_color;
@define-color wm_util shade(@theme_bg_color, 1.2);
@define-color wm_unfocus shade(@theme_bg_color, 1.05);

@import url("gtk-main-common.css");
@import url("gtk-widgets.css");
@import url("gtk-widgets-assets.css");
