/***********************************************************************
 * This section can be modified to create color variants of the theme. *
 ***********************************************************************/

/****************
 * color scheme *
 ****************/

@define-color theme_base_color #ffffff;

@define-color theme_bg_color #edeceb;
@define-color theme_fg_color #000000;

@define-color theme_selected_bg_color #86abd9;
@define-color theme_selected_fg_color #ffffff;

@define-color theme_tooltip_bg_color #f5f5b5;
@define-color theme_tooltip_fg_color #000000;

@define-color theme_text_color #1a1a1a;

@define-color link_color #0000ee;
@define-color visited_link_color #551a8b;

/*****************
 * error/warning *
 *****************/

@define-color error_color #cc0000;

@define-color warning_bg_color #faad3d;

/***************
 * core colors *
 ***************/

/* Core colors are only used in the current file, as bases for other
   color declarations. */

@define-color core_color_a #a4c2e8; /* Core color for blue widgets in Clearlooks-Phenix. */
@define-color core_color_b #edeceb; /* Core color for gray widgets in Clearlooks-Phenix. */

/********************************************
 * End of configuration for color variants. *
 ********************************************/

