/* Borders */

/* generic element borders */
.entry,
GtkComboBox.combobox-entry .entry,
GtkComboBox.combobox-entry .button,
.button:active,
.spinbutton.vertical .button:active,
.inline-toolbar.toolbar.vertical .button:active,
.titlebar .titlebutton:active,
.titlebar .titlebutton:active:hover {
	border-image: url("borders/button-active.png") 3 4 4 4 / 3px 4px 4px 4px stretch;
	border-radius: 4px;
	border-width: 2px;
	border-style: solid;
	border-color: transparent;
}

.entry:insensitive,
GtkComboBox.combobox-entry .entry:insensitive,
GtkComboBox.combobox-entry .button:insensitive,
.button:active:insensitive,
.spinbutton.vertical .button:insensitive,
.inline-toolbar.toolbar.vertical .button:insensitive,
.inline-toolbar.toolbar.vertical .button.default:insensitive {
	border-image: url("borders/button-active-ins.png") 3 4 4 4 / 3px 4px 4px 4px stretch;
	border-radius: 4px;
	border-width: 2px;
	border-style: solid;
	border-color: transparent;
}

.trough row {
	border-image: url("borders/nohl-generic-border.png") 3 / 3px stretch; /* Zuki note: figure out the heck it does */
	border-radius: 4px;
	border-width: 1px;
	border-style: solid;
	border-color: transparent;
}

/* focused element borders */
.entry:focus,
GtkComboBox.combobox-entry .entry:focus,
.button.default:active,
.inline-toolbar.toolbar.vertical .button.default:active {
	border-image: url("borders/button-active-focus.png") 3 4 4 4 / 3px 4px 4px 4px stretch;
	border-radius: 4px;
	border-width: 2px;
	border-style: solid;
	border-color: transparent;
}

/* generic button borders */
.button,
.titlebar .titlebutton:hover
/*.spinbutton.vertical .button,
.inline-toolbar.toolbar.vertical .button*/ {
	border-image: url("borders/button.png") 3 4 4 4 / 3px 4px 4px 4px stretch;
	border-radius: 4px;
	border-width: 2px;
	border-style: solid;
	border-color: transparent;
}

.spinbutton.vertical .button,
.inline-toolbar.toolbar.vertical .button {
	border-image: url("borders/button.png") 3 3 4 3 / 3px 3px 4px 3px stretch;
	border-radius: 4px;
	border-width: 2px;
	border-style: solid;
	border-color: transparent;
}

/* focused button borders */
.button.default,
.button:focus { 
	border-image: url("borders/button-focus.png") 3 4 4 4 / 3px 4px 4px 4px stretch;
	border-radius: 4px;
	border-width: 2px;
	border-style: solid;
	border-color: transparent;
}

/* insensitive button borders */
.button:insensitive,
.button.default:insensitive {
	border-image: url("borders/button-ins.png") 3 4 4 4 / 3px 4px 4px 4px stretch;
}

/* primary toolbar button borders */
.primary-toolbar .button:hover {
	border-image: url("borders/button.png") 3 3 4 3 / 3px 3px 4px 3px stretch;
	background-color: transparent;
}

.primary-toolbar .button:active {
	border-image: url("borders/button-active.png") 3 3 4 3 / 3px 3px 4px 3px stretch;
	background-color: transparent;
}

/* tooltip elements borders */
.tooltip .entry {
	border-image: url("borders/button-active.png") 3 3 4 3 / 3px 3px 4px 3px stretch;
	border-width: 1px;
	border-style: solid;
	border-color: transparent;
}

.tooltip .button {
	border-image: url("borders/button.png") 3 3 4 3 / 3px 3px 4px 3px stretch;
	border-width: 1px;
	border-style: solid;
	border-color: transparent;
}

/* tooltip focused elements borders */
.tooltip .entry:focus {
	border-image: url("borders/button-focus.png") 3 3 4 3 / 3px 3px 4px 3px stretch;
	border-width: 1px;
	border-style: solid;
	border-color: transparent;
}

/* primary toolbar - generic element borders */
.primary-toolbar .entry,
.primary-toolbar GtkComboBox.combobox-entry .entry,
.primary-toolbar GtkComboBox.combobox-entry .button,
.primary-toolbar .button:active,
.primary-toolbar .button.raised:active,
.primary-toolbar .raised .button:active,
.inline-toolbar.toolbar .button:active,
.primary-toolbar GtkComboBox .button:active {
	border-image: url("borders/button-active.png") 3 3 4 3 / 3px 3px 4px 3px stretch;
	border-radius: 3px;
	border-width: 2px;
	border-style: solid;
	border-color: transparent;
}

.primary-toolbar .button.raised:insensitive,
.primary-toolbar .raised .button:insensitive,
.primary-toolbar .button.raised.default:insensitive,
.primary-toolbar .raised .button.default:insensitive,
.inline-toolbar.toolbar .button.default:insensitive,
.inline-toolbar.toolbar .button:insensitive,
.primary-toolbar GtkComboBox .button:insensitive {
	border-image: url("borders/button-active-ins.png") 3 3 4 3 / 3px 3px 4px 3px stretch;
	border-radius: 4px;
	border-width: 2px;
	border-style: solid;
	border-color: transparent;
}

/* primary toolbar - focused element borders */
.primary-toolbar .button:active:focus,
.primary-toolbar .entry:focus,
.primary-toolbar GtkComboBox.combobox-entry .entry:focus,
.primary-toolbar .button.raised.default:active,
.primary-toolbar .raised .button.default:active,
.inline-toolbar.toolbar .button.default:active {
	/*border-image: url("borders/primary-toolbar-generic-border-focused.png") 4 / 4px stretch;*/
	border-image: url("borders/button-active-focus.png") 3 3 4 3 / 3px 3px 4px 3px stretch;
	border-radius: 4px;
	border-width: 2px;
	border-style: solid;
	border-color: transparent;
}

/* primary toolbar - generic button borders */
.primary-toolbar .button.raised,
.primary-toolbar .raised .button,
.inline-toolbar.toolbar .button,
.primary-toolbar GtkComboBox .button {
	border-image: url("borders/button.png") 3 3 4 3 / 3px 3px 4px 3px stretch;
	border-radius: 4px;
	border-width: 2px;
	border-style: solid;
	border-color: transparent;
}

/* primary toolbar - focused button borders */
.primary-toolbar .button.raised.default,
.primary-toolbar .raised .button.default,
.inline-toolbar.toolbar .button.default {
	border-image: url("borders/button.png") 3 3 4 3 / 3px 3px 4px 3px stretch;
	border-radius: 3px;
	border-width: 2px;
	border-style: solid;
	border-color: transparent;
}

.primary-toolbar .button.raised.default,
.primary-toolbar .raised .button.default,
.inline-toolbar.toolbar .button.default {
	/*border-image: url("borders/primary-toolbar-button-border-default.png") 4 / 4px stretch;*/
	border-image: url("borders/button-focus.png") 3 3 4 3 / 3px 3px 4px 3px stretch;
	border-radius: 4px;
	border-width: 2px;
	border-style: solid;
	border-color: transparent;
}

/* column-headers borders */
column-header.button,
column-header .button,
column-header.button:active,
column-header .button:active,
column-header.button:active:hover,
column-header .button:active:hover,
column-header.button:insensitive,
column-header .button:insensitive {
	border-width: 0 1px 1px 0;
	border-radius: 0;
	border-style: solid;
	border-color: transparent;
}

column-header.button,
column-header .button,
column-header.button:active,
column-header .button:active,
column-header.button:active:hover,
column-header .button:active:hover,
column-header .button.dnd {
	border-image: linear-gradient(to top,
		alpha(@theme_base_color, 0.0),
		@theme_bg_color) 0 1 1 0;
}

column-header.button:insensitive,
column-header .button:insensitive {
	border-image: linear-gradient(to top,
		alpha(@theme_base_color, 0.0),
		@insensitive_bg_color) 0 1 1 0;
}

column-header.button:last-child,
column-header:last-child .button,
column-header.button:last-child:active,
column-header:last-child .button:active,
column-header.button:last-child:active:hover,
column-header:last-child .button:active:hover {
	border-right-width: 0;
}

/* pushed colored buttons borders */
.selection-mode.toolbar .suggested-action.button,
.selection-mode.toolbar GtkToolButton.suggested-action .button {
	border-image: url("borders/button.png") 3 3 4 3 / 3px 3px 4px 3px stretch;
	border-radius: 4px;
	border-width: 0px 0px 1px 0px;
	border-style: solid;
	border-color: transparent;

}

/* suggested action buttons borders */
.suggested-action.button,
.suggested-action.button:active {
	border-image: url("borders/button.png") 3 3 4 3 / 3px 3px 4px 3px stretch;
	border-radius: 4px;
	border-width: 1px 1px 2px 1px;
	border-style: solid;
	border-color: transparent;
	/* Zuki note: figure out the heck it does */
}

/* destructive action buttons borders */
.destructive-action.button,
.destructive-action.button:active {
	border-image: url("borders/button.png") 3 3 4 3 / 3px 3px 4px 3px stretch;
	border-radius: 4px;
	border-width: 1px 1px 2px 1px;
	border-style: solid;
	border-color: transparent;
	/* Zuki note: figure out the heck it does */
}
